function[] = alpha(mro,lowbound)

% Parameters: 
%   mro==1 if MRO auctions, LTROs otherwise
%   lowbound: lower bound for computing the weights alpha
%
% this file computes \alpha_{i} where \alpha_{i} is the weight in the
% convex combination of the unsecured (EURIBOR)
% and secured rate (EUREPO) which makes it equal to the marginal value:
% interpretation: it is the ratio of collateral accepted also in the secondary
% market to collateral accepted only in the primary market

% It also outputs statistics of occasions of vhats above/below s and u

% in the code, variable alphavar used instead of alpha to distinguish
% filename and variable name

%mro=0; %set this =0 if doing LTRO analysis; =1 if MRO

if mro==1
    load('mv_regression.mat','marg_all','signif','insignif','shade_all','insignif_shade','signif_shade','bids_coeff','bids_data')
    %load('mv_regression_M2_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
    %load('mv_regression_M1_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
    load('nuno.mat','agdata')
    load ecb_data.mat
    load('bidderdata.mat')   
    load('alpha.mat')
    turmoilcutoff=32;
else
%     load('/home/jakub/Matlab/Nuno/ltro/data_ltro.mat')
%     load('/home/jakub/Matlab/Nuno/ecb_ltro_19_M2_733799.mat')
%     load('/home/jakub/Matlab/Nuno/ecb_ltro_19_M2_733797.mat')
    load('data_ltro.mat')
    load('ecb_main_ltro_19_M1_733803.mat')
    turmoilcutoff=11;
    agdata=agdata_ltro;

    %normalizing by subtracting EONIA
    normalized_mv=marg_all-repmat(agdata(:,13),1,size(marg_all,2)).*(marg_all~=0);
    observations=sum(marg_all~=0);
    time=1:1:auctions;
    dummy=(time>turmoilcutoff)';
    signif=[];
    insignif=[];
    for bidder=1:size(marg_all,2)
        if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
           ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), dummy(marg_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat'});
           ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder),dummy(marg_all(:,bidder)~=0) ,'linear',{'yhat','beta','tstat','fstat'});
           if ols_norm.tstat.pval(2,1)<=pvalue % significant turmoil effect
               signif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
           else % insignificant turmoil effect
               insignif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
           end
        end
    end
    bids_data=[];
end

auctions=size(agdata,1);
%agdata: 1st: auction ID 2nd: duration (days) 3rd: min bid q 4th: min bid rate 5th: clearing rate 
%6th: rationing coeff  7th: ex post supply 8th: q-weighted avg bid 9th: total demand
%10th: N 11th: min bid 12th: max bid 13th: EONIA 14th: EUREPO 15th: EURIBOR 
for auc=1:auctions
    for bidder=1:size(marg_all,2)
        if marg_all(auc,bidder)>0
            if (marg_all(auc,bidder)-agdata(auc,15))<0.1 % this trims large marginal value estimates
                alphavar(auc,bidder)=(marg_all(auc,bidder)-agdata(auc,15))/(agdata(auc,14)-agdata(auc,15));           
            else
                alphavar(auc,bidder)=0.1/(agdata(auc,14)-agdata(auc,15));
            end
        end
    end
end
%plot alphavar before and after turmoil separately:
alpha_before=alphavar(1:turmoilcutoff,:);
for i=1:size(alpha_before,1)
    temp=[alpha_before(i,:)' i*ones(size(alpha_before,2),1)];
    temp=temp(temp(:,1)>=-5 & temp(:,1)<=1 & temp(:,1)~=0,:);
    figure(1)
    scatter(temp(:,2), temp(:,1),5)
    hold on
    if mro==1
        title('Alpha in MROs before turmoil')
    else
        title('Alpha in LTROs before turmoil')
    end
end
alpha_after=alphavar(turmoilcutoff:end,:);
for i=1:size(alpha_after,1)
    temp=[alpha_after(i,:)' i*ones(size(alpha_after,2),1)];
    temp=temp(temp(:,1)>=-5 & temp(:,1)<=1 & temp(:,1)~=0,:);
    figure(2)
    scatter(temp(:,2), temp(:,1),5)
    hold on
    if mro==1
        title('Alpha in MROs after turmoil')
    else
        title('Alpha in LTROs after turmoil')
    end
end

%plot alphavar over all auctions
for i=1:auctions
    temp=[alphavar(i,:)' i*ones(size(alphavar,2),1)];
    temp=temp(temp(:,1)>=-5 & temp(:,1)<=1 & temp(:,1)~=0,:);
    figure(3)
    scatter(temp(:,2), temp(:,1),5)
    hold on
    if mro==1
        title('Alpha in MROs')
    else
        title('Alpha in LTROs')
    end
    axis([0,auctions+1, lowbound,1])
end


if mro==1 %otherwise DAX is not matched to ltro auction dates yet
    plot(1:auctions,dax./(max(dax)-min(dax))-5)
    
    %Now correlation between dax and average alphavar:
    for i=1:auctions
        ind=alphavar(i,:)>-5 & alphavar(i,:)<1 & alphavar(i,:)~=0 ;
        alpha_avg(i,1)=mean(alphavar(i,ind));
    end
    corr(dax,alpha_avg)
    corr(dax(2:end),alpha_avg(1:end-1))
    corr(dax(3:end),alpha_avg(1:end-2))

    dax_diff=dax(2:end)-dax(1:end-1);
    corr(dax_diff,alpha_avg(1:end-1))
    corr(dax_diff(2:end),alpha_avg(1:end-2))
    corr(dax_diff(3:end),alpha_avg(1:end-3))
    
    plot(1:auctions-1,dax_diff./(max(dax_diff)-min(dax_diff)),'-r')
end


%plot an example bidder
if mro==1
    figure(4)
    plot(alphavar(alphavar(:,3)>lowbound & alphavar(:,3)<1,3))
else
    figure(4)
    plot(alphavar(alphavar(:,3)>lowbound & alphavar(:,2)<1,2))
end
%AVERAGE alphavar ACROSS ALL BIDDER PRE- AND POST-TURMOIL:
ind=alphavar(1:turmoilcutoff,:)~=0 & alphavar(1:turmoilcutoff,:)>lowbound & alphavar(1:turmoilcutoff,:)<1;
temp=reshape(alphavar(1:turmoilcutoff,:).*ind,size(alphavar(1:turmoilcutoff,:),1)*size(alphavar(1:turmoilcutoff,:),2),1);
disp(['Pre-Turmoil ratio of good colat to all colat: ' num2str(mean(temp(temp~=0)))])

ind=alphavar(turmoilcutoff+1:auctions,:)~=0 & alphavar(turmoilcutoff+1:auctions,:)>lowbound & alphavar(turmoilcutoff+1:auctions,:)<1;
temp=reshape(alphavar(turmoilcutoff+1:auctions,:).*ind,size(alphavar(turmoilcutoff+1:auctions,:),1)*size(alphavar(turmoilcutoff+1:auctions,:),2),1);
disp(['Post-Turmoil ratio of good colat to all colat: ' num2str(mean(temp(temp~=0)))])

%NOW CONDITION ON TROUBLED BIDDERS:
signif_alpha=[];
for bidder=1:size(marg_all,2)
    if any(signif(:,1)==bidder)
        signif_alpha(:,end+1)=alphavar(:,bidder); 
    end
end
ind=signif_alpha(1:turmoilcutoff,:)~=0 & signif_alpha(1:turmoilcutoff,:)>lowbound & signif_alpha(1:turmoilcutoff,:)<1;
temp=reshape(signif_alpha(1:turmoilcutoff,:).*ind,size(signif_alpha(1:turmoilcutoff,:),1)*size(signif_alpha(1:turmoilcutoff,:),2),1);
disp(['Pre-Turmoil ratio of good colat to all colat for affected bidders: ' num2str(mean(temp(temp~=0)))])
ind=signif_alpha(turmoilcutoff+1:auctions,:)~=0 & signif_alpha(turmoilcutoff+1:auctions,:)>lowbound & signif_alpha(turmoilcutoff+1:auctions,:)<1;
temp=reshape(signif_alpha(turmoilcutoff+1:auctions,:).*ind,size(signif_alpha(turmoilcutoff+1:auctions,:),1)*size(signif_alpha(turmoilcutoff+1:auctions,:),2),1);
disp(['Post-Turmoil ratio of good colat to all colat for affected bidders: ' num2str(mean(temp(temp~=0)))])


insignif_alpha=[];
for bidder=1:size(marg_all,2)
    if any(insignif(:,1)==bidder)
        insignif_alpha(:,end+1)=alphavar(:,bidder); 
    end
end
ind=insignif_alpha(1:turmoilcutoff,:)~=0 & insignif_alpha(1:turmoilcutoff,:)>lowbound & insignif_alpha(1:turmoilcutoff,:)<1;
temp=reshape(insignif_alpha(1:turmoilcutoff,:).*ind,size(insignif_alpha(1:turmoilcutoff,:),1)*size(insignif_alpha(1:turmoilcutoff,:),2),1);
disp(['Pre-Turmoil ratio of good colat to all colat for unaffected bidders: ' num2str(mean(temp(temp>0)))])
ind=insignif_alpha(turmoilcutoff+1:auctions,:)~=0 & insignif_alpha(turmoilcutoff+1:auctions,:)>lowbound & insignif_alpha(turmoilcutoff+1:auctions,:)<1;
temp=reshape(insignif_alpha(turmoilcutoff+1:auctions,:).*ind,size(insignif_alpha(turmoilcutoff+1:auctions,:),1)*size(insignif_alpha(turmoilcutoff+1:auctions,:),2),1);
disp(['Pre-Turmoil ratio of good colat to all colat for unaffected bidders: ' num2str(mean(temp(temp>0)))])

% post-turmoil: find v_i>u_i - and interpret as approximate true u_i (as if
% \alphavar=0)
%ind=alphavar(1:turmoilcutoff,:)>0 & alphavar(1:turmoilcutoff,:)<1;
ind=[];
ind_less=[];
for bidder=1:size(marg_all,2)
    ind(:,bidder)=marg_all(:,bidder)>agdata(:,15);
    ind_less(:,bidder)=marg_all(:,bidder)<=agdata(:,15) & marg_all(:,bidder)>0;
end
disp(['Total number of v_i>u_i: ' num2str(sum(sum(ind)))])
disp(['Total number of v_i>u_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:))))])
disp(['Total number of v_i>u_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:))))])
disp(['Total number of v_i>u_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1)))))])
disp(['Total number of v_i>u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1)))))])
disp(['Total number of v_i>u_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1)))))])
disp(['Total number of v_i>u_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1)))))])
disp(['Total number of v_i>u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1)))))])
disp(['Total number of v_i>u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1)))))])

disp(['Total number of v_i<=u_i: ' num2str(sum(sum(ind_less)))])
disp(['Total number of v_i<=u_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:))))])
disp(['Total number of v_i<=u_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:))))])
disp(['Total number of v_i<=u_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1)))))])
disp(['Total number of v_i<=u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1)))))])
disp(['Total number of v_i<=u_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1)))))])
disp(['Total number of v_i<=u_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1)))))])
disp(['Total number of v_i<=u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1)))))])
disp(['Total number of v_i<=u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1)))))])

%%%%%%%% NOW SECURED RATE %%%%%%%%%%
ind=[];
ind_less=[];
for bidder=1:size(marg_all,2)
    ind(:,bidder)=marg_all(:,bidder)>agdata(:,14);
    ind_less(:,bidder)=marg_all(:,bidder)<=agdata(:,14) & marg_all(:,bidder)>0;
end
disp(['Total number of v_i>s_i: ' num2str(sum(sum(ind)))])
disp(['Total number of v_i>s_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:))))])
disp(['Total number of v_i>s_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:))))])
disp(['Total number of v_i>s_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1)))))])
disp(['Total number of v_i>s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1)))))])
disp(['Total number of v_i>s_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1)))))])
disp(['Total number of v_i>s_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1)))))])
disp(['Total number of v_i>s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1)))))])
disp(['Total number of v_i>s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1)))))])

disp(['Total number of v_i<=s_i: ' num2str(sum(sum(ind_less)))])
disp(['Total number of v_i<=s_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:))))])
disp(['Total number of v_i<=s_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:))))])
disp(['Total number of v_i<=s_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1)))))])
disp(['Total number of v_i<=s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1)))))])
disp(['Total number of v_i<=s_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1)))))])
disp(['Total number of v_i<=s_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1)))))])
disp(['Total number of v_i<=s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1)))))])
disp(['Total number of v_i<=s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1)))))])

%Same reports as above but normalized to per auction:
ind=[];
ind_less=[];
for bidder=1:size(marg_all,2)
    ind(:,bidder)=marg_all(:,bidder)>agdata(:,15);
    ind_less(:,bidder)=marg_all(:,bidder)<=agdata(:,15) & marg_all(:,bidder)>0;
end
disp(['Total number of v_i>u_i: ' num2str(sum(sum(ind))/auctions)])
disp(['Total number of v_i>u_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of v_i>u_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of v_i>u_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1))))/auctions)])
disp(['Total number of v_i>u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i>u_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of v_i>u_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1))))/auctions)])
disp(['Total number of v_i>u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i>u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

disp(['Total number of v_i<=u_i: ' num2str(sum(sum(ind_less))/auctions)])
disp(['Total number of v_i<=u_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of v_i<=u_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of v_i<=u_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1))))/auctions)])
disp(['Total number of v_i<=u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i<=u_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of v_i<=u_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1))))/auctions)])
disp(['Total number of v_i<=u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i<=u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

%%%%%%%% NOW SECURED RATE %%%%%%%%%%
ind=[];
ind_less=[];
for bidder=1:size(marg_all,2)
    ind(:,bidder)=marg_all(:,bidder)>agdata(:,14);
    ind_less(:,bidder)=marg_all(:,bidder)<=agdata(:,14) & marg_all(:,bidder)>0;
end
disp(['Total number of v_i>s_i: ' num2str(sum(sum(ind))/auctions)])
disp(['Total number of v_i>s_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of v_i>s_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of v_i>s_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1))))/auctions)])
disp(['Total number of v_i>s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i>s_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of v_i>s_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1))))/auctions)])
disp(['Total number of v_i>s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i>s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

disp(['Total number of v_i<=s_i: ' num2str(sum(sum(ind_less))/auctions)])
disp(['Total number of v_i<=s_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of v_i<=s_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of v_i<=s_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1))))/auctions)])
disp(['Total number of v_i<=s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i<=s_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of v_i<=s_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1))))/auctions)])
disp(['Total number of v_i<=s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of v_i<=s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

if isempty(bids_data)==1 %ltro
    bids_data=[];
    counter=1;     
    for i=2:size(data,1)
        if data(i-1,3)~=data(i,3), counter=1; else counter=counter+1; end
        if i<size(data,1)
            if data(i,3)~=data(i+1,3)
                temp=0;
                temp=data(i-counter+1:i,5)'*data(i-counter+1:i,6)/sum(data(i-counter+1:i,6));                
                bids_data=[bids_data; data(i,2) data(i,3) temp  ]; % record auction, bidder, q-wgtd bid
            end
        else %I know it is the same bidder on the last line in data
            temp=data(i-counter+1:i,5)'*data(i-counter+1:i,6)/sum(data(i-counter+1:i,6));                
            bids_data=[bids_data; data(i,2) data(i,3) temp]; % record auction, bidder, q-wgtd bid
        end
    end
    %Sort by bidders:
    bids_data=sortrows(bids_data,[2 1 3]);
    bids_data(:,4)=bids_data(:,1)>20070051;
end
%%% SAME EXERCISE AS ABOVE BUT COMPARING BIDS TO u_t and s_t:
for i=1:auctions
    bids_data(bids_data(:,1)==agdata(i,1),5)=agdata(i,13); %eonia rate
    bids_data(bids_data(:,1)==agdata(i,1),6)=agdata(i,14); %repo rate
    bids_data(bids_data(:,1)==agdata(i,1),7)=agdata(i,15); %euribor rate
end
%Now reshape the bids into same format as marg_all:
bids_all=zeros(size(marg_all));
for i=1:auctions
    bids_all(i,bids_data(bids_data(:,1)==agdata(i,1),2))=bids_data(bids_data(:,1)==agdata(i,1),3);
end
ind=[];
ind_less=[];
for bidder=1:size(bids_all,2)
    ind(:,bidder)=bids_all(:,bidder)>agdata(:,15);
    ind_less(:,bidder)=bids_all(:,bidder)<=agdata(:,15) & bids_all(:,bidder)>0;
end
disp(['Total number of b_i>u_i: ' num2str(sum(sum(ind))/auctions)])
disp(['Total number of b_i>u_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of b_i>u_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of b_i>u_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1))))/auctions)])
disp(['Total number of b_i>u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i>u_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of b_i>u_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1))))/auctions)])
disp(['Total number of b_i>u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i>u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

disp(['Total number of b_i<=u_i: ' num2str(sum(sum(ind_less))/auctions)])
disp(['Total number of b_i<=u_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of b_i<=u_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of b_i<=u_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1))))/auctions)])
disp(['Total number of b_i<=u_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i<=u_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of b_i<=u_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1))))/auctions)])
disp(['Total number of b_i<=u_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i<=u_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

%%%%%%%% NOW SECURED RATE %%%%%%%%%%
ind=[];
ind_less=[];
for bidder=1:size(bids_all,2)
    ind(:,bidder)=bids_all(:,bidder)>agdata(:,14);
    ind_less(:,bidder)=bids_all(:,bidder)<=agdata(:,14) & bids_all(:,bidder)>0;
end
disp(['Total number of b_i>s_i: ' num2str(sum(sum(ind))/auctions)])
disp(['Total number of b_i>s_i pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of b_i>s_i post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of b_i>s_i significantly affected bidders: ' num2str(sum(sum(ind(:,signif(:,1))))/auctions)])
disp(['Total number of b_i>s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i>s_i significantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of b_i>s_i insignificantly affected bidders: ' num2str(sum(sum(ind(:,insignif(:,1))))/auctions)])
disp(['Total number of b_i>s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i>s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

disp(['Total number of b_i<=s_i: ' num2str(sum(sum(ind_less))/auctions)])
disp(['Total number of b_i<=s_i pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,:)))/turmoilcutoff)])
disp(['Total number of b_i<=s_i post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,:)))/18)])
disp(['Total number of b_i<=s_i significantly affected bidders: ' num2str(sum(sum(ind_less(:,signif(:,1))))/auctions)])
disp(['Total number of b_i<=s_i significantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,signif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i<=s_i significantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,signif(:,1))))/18)])
disp(['Total number of b_i<=s_i insignificantly affected bidders: ' num2str(sum(sum(ind_less(:,insignif(:,1))))/auctions)])
disp(['Total number of b_i<=s_i insignificantly affected pre-turmoil: ' num2str(sum(sum(ind_less(1:turmoilcutoff,insignif(:,1))))/turmoilcutoff)])
disp(['Total number of b_i<=s_i insignificantly affected post-turmoil: ' num2str(sum(sum(ind_less(turmoilcutoff+1:auctions,insignif(:,1))))/18)])

% bar graph for Ali:
% figure
% bar(a)
% title('Alpha by country (participants only)')
% xlabel('country')
% ylabel('alpha')
% legend('pre-turmoil','post-turmoil')
