function[group1,group2,signif,insignif]=asigngroups(margvalall,data,Group1,Group2,cutoff,premium,pvalue,mro,qregression)
%Routine which figures two groups for asymmetric model at the end of 1st
%iteration

%Most of this code comes from the comparison.m file which runs the main
%regression analysis at the end of estimation

%load ecb_main_50_M1_733747.mat
%clear temp

if nargin<8
    mro=1; %default is MRO analysis
end

if nargin<9
    qregression=0; %default is OLS
end

%First margvalall should have just one column: no bootstrapdraws!
for i=1:size(margvalall,1)
   temp{i,1}=margvalall{i,1}; 
end
margvalall=temp;

if mro==1 %doing MROs
    load('nuno.mat','agdata')
    turmoilcutoff=32;
else    %doing LTROs
    load('data_ltro.mat','agdata_ltro')
    turmoilcutoff=11;
    agdata=agdata_ltro;
end
auctions=size(agdata,1);
%cutoff=6;  % above what rate to trim marginal values
%premium=1; % substitute trimmed marg values by bid+this premium
[margvalall_adj]=margvaladjust(margvalall,data,cutoff,premium);

%compute shading at each step that has been estimated and q-weighted avg
%[shadingall,shading_avg]=shading(margvalall_adj,data);

% Compute quantity-weighted and unweighted averages of marginal values by
% bidder and by auctions
[allavgmarg,allavgmargstd,avgmarg,allavgmarg_unw,allavgmargstd_unw,avgmarg_unw]=avgmargval(margvalall_adj,data);
 
% Obtain which auctions and on which lines in `invbidfunc' and
% `margvalall' in those auctions a bidder identity participates
[bidaddress, frequentbidders, bidderfrequency]=findbidaddress(data);

% Now obtain a matrix of quantity-weighted marginal values and shading by large
% bidders:
marg_all=zeros(auctions,size(bidaddress,1));
%shade_all=zeros(auctions,size(bidaddress,1));
marg_all_unw=zeros(auctions,size(bidaddress,1));
for bidder=1:size(bidaddress,1)
    if bidaddress{bidder,1}(1,3)>0 % few identities never appear in the sample
        for j=1:size(bidaddress{bidder,1},1)
            marg_all(bidaddress{bidder,1}(j,1),bidder)=avgmarg{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
            %shade_all(bidaddress{bidder,1}(j,1),bidder)=shading_avg{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
            marg_all_unw(bidaddress{bidder,1}(j,1),bidder)=avgmarg_unw{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
        end
    end
end
    
%normalizing by subtracting EONIA
normalized_mv=marg_all-repmat(agdata(:,13),1,size(marg_all,2)).*(marg_all~=0);
observations=sum(marg_all~=0);
time=1:1:auctions;
dummy=(time>turmoilcutoff)'; %dummy for post-turmoil auctions
signif=[];
insignif=[];
for bidder=1:size(marg_all,2)
    if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
        if qregression~=1
            ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), dummy(marg_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat'});
            ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder),dummy(marg_all(:,bidder)~=0) ,'linear',{'yhat','beta','tstat','fstat'});
            if ols_norm.tstat.pval(2,1)<=pvalue % significant turmoil effect
                signif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            else % insignificant turmoil effect
                insignif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            end
        else
            X=[ones(size(dummy(marg_all(:,bidder)~=0),1),1) dummy(marg_all(:,bidder)~=0)];
            y=normalized_mv(marg_all(:,bidder)~=0,bidder);
            [beta,beta_std,pvalue_qreg]=rq_fnm(X, y, 0.5);
            if pvalue_qreg(2,1)<=pvalue % significant turmoil effect
                signif(end+1,:)=[bidder observations(1,bidder) beta(2,1) pvalue_qreg(2,1)];
            else % insignificant turmoil effect
                insignif(end+1,:)=[bidder observations(1,bidder) beta(2,1) pvalue_qreg(2,1)];
            end
        end
    end
end

% Now re-assign groups: %bidders that could not be used for regressions
% will be assumed as not problematic and kept in Group1
reasign_group1=[];
reasign_coord1=[];
for i=1:size(Group1,2)
   if any(signif(:,1)==Group1(1,i))
       reasign_coord1=[reasign_coord1 i];
       reasign_group1=[reasign_group1 Group1(1,i)];
   end
end
reasign_group2=[];
reasign_coord2=[];
for i=1:size(Group2,2)
   if any(insignif(:,1)==Group2(1,i)) % re-assign insignificant to Group1
       reasign_coord2=[reasign_coord2 i];
       reasign_group2=[reasign_group2 Group2(1,i)];
   end
   %Bidders that could not be used for regressions (no estimates before and after turmoil) are re-assigned to Group1
   if all(insignif(:,1)~=Group2(1,i)) && all(signif(:,1)~=Group2(1,i))
       reasign_coord2=[reasign_coord2 i];
       reasign_group2=[reasign_group2 Group2(1,i)];
   end
       
end
temp2=Group2;
temp2(reasign_coord2)=[]; %delete entries that were re-assigned
group2=sort([temp2 reasign_group1]); %re-asign identities and group with old ones
temp1=Group1;
temp1(reasign_coord1)=[]; %delete entries that were re-assigned
group1=sort([temp1 reasign_group2]); %re-asign identities and group with old ones
