%function[]=comparison(marg_all,agdata)

%Function 'comparison' computes regressions of quantity-weighted marginal
%values (or bids) of each bidder across auctions on covariates and another
%set of regressions on turmoil dummy and plots histograms of coefficients.

clear
global model pgrid pstep flatval resamplingdraws bidstepscum bidsteps estim bootdraws nbidfun invbidboot oversample supplynoise auctions aucgroupsize Group1 Group2

loaddata=1; %if loading data from scratch and saving preparatory file

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% if bids instead of marginal values to be used in main regressions,  %%%
% set 'usebids'=1 here                                                %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
usebids=0;
ltro=0;

if loaddata==1
    if ltro==0
        %load ecb_main_50_old.mat
        %load ecb_main_mro_50_M3_733846.mat
        %load /home/jakub/Matlab/Nuno/asymmetric/ecb_main_50_M2_733714.mat
        %load /home/jakub/Matlab/Nuno/asymmetric/ecb_main_50_M1_733714.mat
        %load ecb_data.mat
        load  /home/jakub/matlab_results/Nuno/ecb_main_mro_50_M3_B200_734262.mat
        load('nuno.mat','agdata') 
        % agdata: 5th c: clearing rates, 13th: EONIA swap, 14th: repo rate
        %        15th: EURIBOR (unsecured) rate    
        load('bidderdata.mat')
    else
        %load ecb_main_ltro_19_M3_733841.mat
        %load ecb_main_ltro_19_M2_733815.mat
        load ecb_main_ltro_19_M1_733816.mat
        load('/home/jakub/Matlab/Nuno/data_ltro.mat','data_ltro_numbers','agdata_ltro')
        data=data_ltro_numbers;
        agdata=agdata_ltro;        
    end
    turmoilcutoff=find(agdata(:,1)>20070051,1,'first')-1;
    auctions=size(agdata,1);
    if exist('pvalue','var')==0
        pvalue=0.05;
    end

    if ltro==0
        % Adjust marginal values: kill outliers above cutoff (3rd argument) by replacing them with
        % bid + fixed premium (4th argument is `premium`), and make them strictly
        % decreasing by at least `pstep` per step
        %%
        cutoff=6;  % above what rate to trim marginal values
        premium=0.25; % substitute trimmed marg values by bid+this premium
        [margvalall_adj]=margvaladjust(margvalall,data,cutoff,premium);
        %%
        % Compute quantity-weighted and unweighted averages of marginal values by
        % bidder and by auctions
        [allavgmarg,allavgmargstd,avgmarg,allavgmarg_unw,allavgmargstd_unw,avgmarg_unw]=avgmargval(margvalall_adj,data);
        
        % Obtain which auctions and on which lines in `invbidfunc' and
        % `margvalall' in those auctions a bidder identity participates
        [bidaddress, frequentbidders, bidderfrequency]=findbidaddress(data,40);
    end
    
    %compute shading at each step that has been estimated and q-weighted
    %avg
   [shadingall,shading_avg]=shading(margvalall_adj,data);

   
    % Now obtain a matrix of quantity-weighted marginal values and shading by large
    % bidders:
    marg_all=zeros(auctions,size(bidaddress,1));
    shade_all=zeros(auctions,size(bidaddress,1));
    marg_all_unw=zeros(auctions,size(bidaddress,1));
    for bidder=1:size(bidaddress,1)
        if bidaddress{bidder,1}(1,3)>0 % few identities never appear in the sample and should thus be ignored
            for j=1:size(bidaddress{bidder,1},1)
               marg_all(bidaddress{bidder,1}(j,1),bidder)=avgmarg{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
               shade_all(bidaddress{bidder,1}(j,1),bidder)=shading_avg{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
               marg_all_unw(bidaddress{bidder,1}(j,1),bidder)=avgmarg_unw{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
            end
        end
    end
    bids_all=marg_all-shade_all;
    
    %normalizing by subtracting EONIA
    normalized_mv=marg_all-repmat(agdata(:,13),1,size(marg_all,2)).*(marg_all~=0);
    observations=sum(marg_all~=0);
    time=1:1:auctions;
    dummy=(agdata(:,1)>20070051)';
    signif=[];
    insignif=[];
    for bidder=1:size(marg_all,2)
        if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
           ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), dummy(marg_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat'});
           ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder),dummy(marg_all(:,bidder)~=0) ,'linear',{'yhat','beta','tstat','fstat'});
           if ols_norm.tstat.pval(2,1)<=pvalue % significant turmoil effect
               signif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
           else % insignificant turmoil effect
               insignif(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
           end
        end
    end

    % Shading regressions
    signif_shade=[];
    insignif_shade=[];
    for bidder=1:size(shade_all,2)
        if isempty(max(dummy(shade_all(:,bidder)~=0)))==0 && isempty(min(dummy(shade_all(:,bidder)~=0)))==0
            if observations(1,bidder)>2 && max(dummy(shade_all(:,bidder)~=0))~=min(dummy(shade_all(:,bidder)~=0)) %regression only if at least two observations
               ols_shade=regstats(shade_all(shade_all(:,bidder)~=0,bidder), dummy(shade_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat',});
               if ols_shade.tstat.pval(2,1)<=pvalue % significant turmoil effect
                   signif_shade(end+1,:)=[bidder observations(1,bidder) ols_shade.tstat.beta(2,1) ols_shade.tstat.pval(2,1)];
               else % insignificant turmoil effect
                   insignif_shade(end+1,:)=[bidder observations(1,bidder) ols_shade.tstat.beta(2,1) ols_shade.tstat.pval(2,1)];
               end
            end
        end
    end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Now same exercise but using bids: %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bids_data=[];
counter=1; 
data=data(data(:,2)~=20070053 & data(:,2)~=20070090 & data(:,2)~=20070096,:);
for i=2:size(data,1)
    if data(i-1,3)~=data(i,3), counter=1; else counter=counter+1; end
    if i<size(data,1)
        if data(i,3)~=data(i+1,3)
            temp=0;
            temp=data(i-counter+1:i,5)'*data(i-counter+1:i,6)/sum(data(i-counter+1:i,6));                
            bids_data=[bids_data; data(i,2) data(i,3) temp 0 0 0 0 data(i,10)]; % record auction, bidder, q-wgtd bid
        end
    else %I know it is the same bidder on the last line in data
        temp=data(i-counter+1:i,5)'*data(i-counter+1:i,6)/sum(data(i-counter+1:i,6));                
        bids_data=[bids_data; data(i,2) data(i,3) temp 0 0 0 0 data(i,10)]; % record auction, bidder, q-wgtd bid
    end
end
%Sort by bidders:
bids_data=sortrows(bids_data,[2 1 3]);
bids_data(:,4)=bids_data(:,1)>20070051; %first post-turmoil for LTRO is 20070054 

% add interest rates:
for i=1:auctions
    bids_data(bids_data(:,1)==agdata(i,1),5)=agdata(i,13); %eonia rate
    bids_data(bids_data(:,1)==agdata(i,1),7)=agdata(i,15); %euribor rate
    bids_data(bids_data(:,1)==agdata(i,1),6)=agdata(i,14); %eurepo rate
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%  ADD IN THE PAPER %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %overall regression of q-weighted bids on rates
    %without purging the policy rate increases: (high R^2!!!)
    bidreg=regstats(bids_data(:,3),bids_data(:,[5 6]),'linear',{'beta','tstat','rsquare'});
    % THIS PURGING WORKS ONLY FOR MROs - for LTROs to many rate increases
    % during the data span
    %purge bids from the two rate increases:
    ratedummy=bids_data(:,1)>=20070014;
    ratedummy(:,2)=bids_data(:,1)>=20070039;
    temp=regstats(bids_data(:,3),ratedummy,'linear','r');
    purgedbids=temp.r;
    bidreg_purged=regstats(purgedbids,bids_data(:,[5 6]),'linear',{'beta','tstat','rsquare'});
    bidreg_purged_pre=regstats(purgedbids(bids_data(:,4)==0),bids_data(bids_data(:,4)==0,[5 6]),'linear',{'beta','tstat','rsquare'});
    bidreg_purged_post=regstats(purgedbids(bids_data(:,4)==1),bids_data(bids_data(:,4)==1,[5 6]),'linear',{'beta','tstat','rsquare'});

    % this just checks that all positive bids in an auction have an estimated
    % marginal value associated with them
    temp=sortrows(data,[3 2 -5]);
    for i=1:size(temp,1)
        if marg_all(agdata(:,1)==temp(i,2),temp(i,3))==0
            disp(['Not estimated: Bidder ' num2str(temp(i,3))])
            disp(['Auction ' num2str(find(agdata(:,1)==temp(i,2)))])
            %Let it be the bid as it must be that the bid was so low that
            %no simulated residual supply ever realized below this bid
            %marg_all(agdata(:,1)==temp(i,2),temp(i,3))=temp(i,5);
        end
    end
    
    %overall regression of q-weighted values on rates
    %without purging the policy rate increases: (high R^2!!!)
        %construct value data:
        margval_data=[];        
        for i=1:size(marg_all,1)
            for j=1:size(marg_all,2)
                if marg_all(i,j)>0
                    margval_data(end+1,:)=[marg_all(i,j) agdata(i,1) agdata(i,13:15)]; %adding vhat, auctionID, eonia, eurepo, euribor                    
                end
            end
        end
  
        
    mvreg=regstats(margval_data(:,1),bids_data(:,[4 5]),'linear',{'beta','tstat'});%,'rsquare'});
    %purge bids from the two rate increases:
    ratedummy=[];
    ratedummy=margval_data(:,2)>=20070014;
    ratedummy(:,2)=margval_data(:,2)>=20070039;
    temp=regstats(margval_data(:,1),ratedummy,'linear','r');
    purgedmvs=temp.r;
    mvreg_purged=regstats(purgedmvs,margval_data(:,[5 4]),'linear',{'beta','tstat'}); %,'rsquare'});
    mvreg_purged_pre=regstats(purgedmvs(margval_data(:,2)<=20070051),margval_data(margval_data(:,2)<=20070051,[5 4]),'linear',{'beta','tstat'});%,'rsquare'});
    mvreg_purged_post=regstats(purgedmvs(margval_data(:,2)>20070051),margval_data(margval_data(:,2)>20070051,[5 4]),'linear',{'beta','tstat'});%,'rsquare'});
    
    %construct participation measures and correlate with current account
    %measure
    participation=sum(marg_all(:,:)>0);
    if exist('cuac','var')
        for i=1:size(cuac,2)
            temp=cuac(2:end,i);
            meancuac(1,i)=mean(temp(isnan(temp)==0));
        end
        meancuac=[cuac(1,find(isnan(meancuac)==0)) ; meancuac(find(isnan(meancuac)==0))];
        meancuac=meancuac(:,find(meancuac(1,:)>0));
        meancuac=[meancuac ; participation(meancuac(1,:))];
        corr(meancuac(2,:)',meancuac(3,:)')   
    end
    
%bidder-by-bidder regression:
bids_coeff=[];
for i=1:bids_data(end,2)
    if sum(bids_data(:,2)==i)>2
        if min(bids_data(bids_data(:,2)==i,1))<=20070051 && max(bids_data(bids_data(:,2)==i,1))>20070051
           %regress bid-eonia spread on the turmoil dummy
           temp=regstats((bids_data(bids_data(:,2)==i,3)-bids_data(bids_data(:,2)==i,5)), bids_data(bids_data(:,2)==i,[4]) ,'linear',{'beta','tstat'});
           bids_coeff=[bids_coeff; i temp.tstat.beta(2,1) temp.tstat.pval(2,1) ]  ;          
        end
    end
end
disp(['Fraction of bids significantly affected: ' num2str(sum(bids_coeff(:,3)<=pvalue)/size(bids_coeff,1))])

% correlation btw trouble prediction based on bids and on values
trouble=[];
for i=1:bids_data(end,2)
    if sum(signif(:,1)==i)>0
       trouble=[trouble ; i bids_coeff(bids_coeff(:,1)==i,3)<=pvalue 1 ]; 
    end
    if sum(insignif(:,1)==i)>0
       trouble=[trouble ; i bids_coeff(bids_coeff(:,1)==i,3)<=pvalue 0 ]; 
    end
end
disp(['Correlation in trouble prediction: ' mat2str(corrcoef(trouble(:,2),trouble(:,3)))])
disp(['Predicted based on bids, but not on val: ' num2str(sum(trouble(:,2)==1 & trouble(:,3)==0,1))])
disp(['Above as fraction of all: ' num2str(sum(trouble(:,2)==1 & trouble(:,3)==0,1)/size(trouble,1))])
disp(['Above as fraction of predicted by both: ' num2str(sum(trouble(:,2)==1 & trouble(:,3)==0,1)/sum(trouble(:,2)==1 & trouble(:,3)==1,1))])
disp(['Predicted based on values, but not on bids: ' num2str(sum(trouble(:,2)==0 & trouble(:,3)==1,1))])
disp(['Predicted based on both: ' num2str(sum(trouble(:,2)==1 & trouble(:,3)==1,1))])
disp(['Predicted based on neither: ' num2str(sum(trouble(:,2)==0 & trouble(:,3)==0,1))])
%%

% save constructed data
%save('mv_regression.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
%save('mv_regression_M2_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
%save('mv_regression_M1_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
save('mv_regression_M3_B200_734262.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')

else
    %%%%%%%%REPORTED IN THE PAPER:
    %load('mv_regression.mat','marg_all','signif','insignif','shade_all','insignif_shade','signif_shade','bids_coeff','bids_data')
    %%% VERY SIMILAR
    %load('mv_regression_M2_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data') 
    %%% IMPOSING COTINUOUS VALUES EVERYWHERE IS SLIGHTLY DIFFERENT
    %load('mv_regression_M1_733714.mat','marg_all','signif','insignif','signif_shade','insignif_shade','shade_all','bids_coeff','bids_data')
    load('mv_regression_M3_B200_734262.mat')
    load('nuno.mat','agdata')
    load ecb_data.mat
    load('bidderdata.mat')
    auctions=size(agdata,1);
end

bids_all=marg_all-shade_all;

%%%%%%%%%%%%%%%%%%%%%%%%%% EXPORT VALUES %%%%%%%%%%%%%%%%%%
% temp=1:733;
% temp=[temp; marg_all ];
% temp=[ [0; agdata(:,1)] temp];
% savefile=['values_' int2str(round(now)) '.txt'];
% save(savefile,'temp','-ASCII','-tabs')
% 
% %normalize by eonia
% temp_norm=marg_all-repmat(agdata(:,13),1,size(marg_all,2)).*(marg_all~=0);
% temp_norm= [ [0;agdata(:,1)] temp_norm];
% savefile=['values_norm_' int2str(round(now)) '.txt'];
% save(savefile,'temp_norm','-ASCII','-tabs')

%Regress eonia on eurepo
temp=regstats(agdata(:,13),agdata(:,14),'linear',{'beta','tstat','fstat','rsquare'});
         
 

disp('***********************************************************************************************')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Report of mean shading conditional on participation %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
turmoilcutoff=find(agdata(:,1)>20070051,1,'first');
disp(['Mean shading condl on partic overall: ' num2str(mean(shade_all(shade_all>0)))])
disp(['Std Dev shading condl on partic overall: ' num2str(std(shade_all(shade_all>0)))])

temp=shade_all(1:turmoilcutoff,:);
disp(['Mean shading condl on partic BEFORE: ' num2str(mean(temp(temp>0)))])
disp(['Std Dev shading condl on partic BEFORE: ' num2str(std(temp(temp>0)))])

temp=shade_all(turmoilcutoff:end,:);
disp(['Mean shading condl on partic AFTER: '  num2str(mean(temp(temp>0)))])
disp(['Std Dev shading condl on partic AFTER: ' num2str(std(temp(temp>0)))])

if isempty(signif_shade)==0
    disp(['Turmoil increased shading (among significant effects) by: '  num2str(mean(signif_shade(signif_shade(:,3)>0,3)))])
    disp(['Turmoil decreased shading (among significant effects) by: '  num2str(mean(signif_shade(signif_shade(:,3)<0,3)))])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bidder-level data preparation %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% prepare  bidder-level covariates:
% find auction dates in MRR data:
ind_auc=[];
for i=1:auctions
    ind_auc=[ind_auc; find(date_auctions(i,1)==date_mrr)];
end
mrr_data=[mrr(1,:) ; mrr(ind_auc+1,:)];
% find auction dates in CuAc data:
ind_auc=[];
for i=1:auctions
    ind_auc=[ind_auc; find(date_auctions(i,1)==date_cuac)];
end
cuac_data=[cuac(1,:) ; cuac(ind_auc+1,:)];
% find auction dates in CDS data:
ind_auc=[];
for i=1:auctions
    ind_auc=[ind_auc; find(date_auctions(i,1)==date_cds)];
end
cds_data=[cds(1,:) ; cds(ind_auc+1,:)];
% find auction dates in Equity data:
ind_auc=[];
for i=1:auctions
    ind_auc=[ind_auc; find(date_equities(i,1)==date_equities)];
end
equities_data=[equities(1,:) ; equities(ind_auc+1,:)];

% find auction dates in Deficiency data:
ind_auc=[];
for i=1:auctions
    ind_auc=[ind_auc; find(date_auctions(i,1)==date_deficiency)];
end
deficiency_data=[deficiency(1,:) ; deficiency(ind_auc+1,:)];

%%extract additional file for Nuno"
% AT20111 BEARTEBEBB FI16802358 FR30004 FR31489 FR30056 FR30003 DE00321 DE00317 DE00003 DE00001 DE00002 IEAIBPLC
% IEBKIREL IT03135 IT01030 IT03207 NL150 NL600 NL163 ES0182 ES0049
% IEAIBPLC is not in our data
% extractgroup=[11 23 572 584 591 588 583 58 55 32 30 31 609 643 634 645 706 712 707 522 514];
% for i=1:size(extractgroup,2)
%     included(i)=any(mv_cuac_equit2(:,1)==extractgroup(1,i));
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%   REGRESSIONS %%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

turmoilcutoff=find(agdata(:,1)>20070051,1,'first');
% regressions on interaction of turmoil dummy and participation frequency
normalized_mv=marg_all-repmat(agdata(:,13),1,size(marg_all,2)).*(marg_all~=0);
observations=sum(marg_all~=0);
observations_pre=sum(marg_all(1:turmoilcutoff,:)~=0);
observations_post=sum(marg_all(turmoilcutoff+1:end,:)~=0);

time=1:1:auctions;
dummy=(time>32)';
dummy_int=repmat(dummy,1,5);
signif_inter_freq=[];
insignif_inter_freq=[];
signif_inter_infreq=[];
insignif_inter_infreq=[];

for bidder=1:size(marg_all,2)
    if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
        if observations_pre(1,bidder)>20 % frequent participant before turmoil            
            ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), dummy(marg_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat'});
            ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder),dummy(marg_all(:,bidder)~=0) ,'linear',{'yhat','beta','tstat','fstat'});
            if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                signif_inter_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            else % insignificant turmoil effect
                insignif_inter_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            end
        else
            dummy_int=[dummy zeros(50,1)];
            ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), dummy(marg_all(:,bidder)~=0),'linear',{'yhat','beta','tstat','fstat'});
            ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder),dummy(marg_all(:,bidder)~=0) ,'linear',{'yhat','beta','tstat','fstat'});
            if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                signif_inter_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            else % insignificant turmoil effect
                insignif_inter_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2,1) ols_norm.tstat.pval(2,1)];
            end
        end       
    end
end

% using bidder covariates: reserves, deficiency and stock prices
disp(['There is ' num2str(size(find(cuac_data(1,:)>0),2)) ' bidders in auction data and current account data.'])
disp(['There is ' num2str(size(find(deficiency_data(1,:)>0),2)) ' bidders in auction data and deficiency data.'])
disp(['There is ' num2str(size(find(equities_data(1,:)>0),2)) ' bidders in auction data and equities data.'])

%CuAc
cuac_data_temp=cuac_data(2:end,find(cuac_data(1,:)>0));
cuac_data_temp=reshape(cuac_data_temp, size(cuac_data_temp,1)*size(cuac_data_temp,2),1);
disp(['Mean CuAc banks also in bidding data: ' num2str(mean(cuac_data_temp(isnan(cuac_data_temp)==0)))])
disp(['St Dev CuAc banks also in bidding data: ' num2str(std(cuac_data_temp(isnan(cuac_data_temp)==0)))])
cuac_data_temp=cuac_data(2:end,:);
cuac_data_temp=reshape(cuac_data_temp, size(cuac_data_temp,1)*size(cuac_data_temp,2),1);
disp(['Mean CuAc all banks: ' num2str(mean(cuac_data_temp(isnan(cuac_data_temp)==0)))])
disp(['St Dev CuAc all banks: ' num2str(std(cuac_data_temp(isnan(cuac_data_temp)==0)))])

%MRR
mrr_data_temp=mrr_data(2:end,find(mrr_data(1,:)>0));
mrr_data_temp=reshape(mrr_data_temp, size(mrr_data_temp,1)*size(mrr_data_temp,2),1);
disp(['Mean MRR banks also in bidding data: ' num2str(mean(mrr_data_temp(isnan(mrr_data_temp)==0)))])
disp(['St Dev MRR banks also in bidding data: ' num2str(std(mrr_data_temp(isnan(mrr_data_temp)==0)))])
mrr_data_temp=mrr_data(2:end,:);
mrr_data_temp=reshape(mrr_data_temp, size(mrr_data_temp,1)*size(mrr_data_temp,2),1);
disp(['Mean MRR all banks: ' num2str(mean(mrr_data_temp(isnan(mrr_data_temp)==0)))])
disp(['St Dev MRR all banks: ' num2str(std(mrr_data_temp(isnan(mrr_data_temp)==0)))])

%Ratio of CuAc to MRR:
mrr_data_temp=mrr_data(2:end,find(mrr_data(1,:)>0));
mrr_data_temp=reshape(mrr_data_temp, size(mrr_data_temp,1)*size(mrr_data_temp,2),1);
cuac_data_temp=cuac_data(2:end,find(cuac_data(1,:)>0));
cuac_data_temp=reshape(cuac_data_temp, size(cuac_data_temp,1)*size(cuac_data_temp,2),1);
mrrcuac=cuac_data_temp./mrr_data_temp;
disp(['Mean CuAc/MRR banks also in bidding data: ' num2str(mean(mrrcuac(isnan(mrrcuac)==0)))])
disp(['St Dev CuAc/MRR banks also in bidding data: ' num2str(std(mrrcuac(isnan(mrrcuac)==0)))])
mrr_data_temp=mrr_data(2:end,:);
mrr_data_temp=reshape(mrr_data_temp, size(mrr_data_temp,1)*size(mrr_data_temp,2),1);
cuac_data_temp=cuac_data(2:end,:);
cuac_data_temp=reshape(cuac_data_temp, size(cuac_data_temp,1)*size(cuac_data_temp,2),1);
mrrcuac=cuac_data_temp./mrr_data_temp;
disp(['Mean CuAc/MRR all banks: ' num2str(mean(mrrcuac(isnan(mrrcuac)==0)))])
disp(['St Dev CuAc/MRR all banks: ' num2str(std(mrrcuac(isnan(mrrcuac)==0)))])

%Deficiency
deficiency_data_temp=deficiency_data(2:end,find(deficiency_data(1,:)>0));
deficiency_data_temp=reshape(deficiency_data_temp, size(deficiency_data_temp,1)*size(deficiency_data_temp,2),1);
disp(['Mean deficiency banks also in bidding data: ' num2str(mean(deficiency_data_temp(isnan(deficiency_data_temp)==0)))])
disp(['St Dev deficiency banks also in bidding data: ' num2str(std(deficiency_data_temp(isnan(deficiency_data_temp)==0)))])
deficiency_data_temp=deficiency_data(2:end,:);
deficiency_data_temp=reshape(deficiency_data_temp, size(deficiency_data_temp,1)*size(deficiency_data_temp,2),1);
disp(['Mean deficiency all banks: ' num2str(mean(deficiency_data_temp(isnan(deficiency_data_temp)==0)))])
disp(['St Dev deficiency all banks: ' num2str(std(deficiency_data_temp(isnan(deficiency_data_temp)==0)))])
disp(['Mean deficiency (condl on >0) all banks: ' num2str(mean(deficiency_data_temp(isnan(deficiency_data_temp)==0 & deficiency_data_temp>0)))])
disp(['St Dev deficiency (condl on >0) all banks: ' num2str(std(deficiency_data_temp(isnan(deficiency_data_temp)==0 & deficiency_data_temp>0)))])

%Equities
equit_data_temp=equities_data(2:end,find(equities_data(1,:)>0));
equit_data_temp=reshape(equit_data_temp, size(equit_data_temp,1)*size(equit_data_temp,2),1);
disp(['Mean stock price banks also in bidding data: ' num2str(mean(equit_data_temp(isnan(equit_data_temp)==0)))])
disp(['St Dev stock price banks also in bidding data: ' num2str(std(equit_data_temp(isnan(equit_data_temp)==0)))])
equit_data_temp=equities_data(2:end,:);
equit_data_temp=reshape(equit_data_temp, size(equit_data_temp,1)*size(equit_data_temp,2),1);
disp(['Mean stock price all banks: ' num2str(mean(equit_data_temp(isnan(equit_data_temp)==0)))])
disp(['St Dev stock price all banks: ' num2str(std(equit_data_temp(isnan(equit_data_temp)==0)))])

%which bidders in both covariates data-sets
samebidder=[];
for i=1:size(equities_data,2)
    if equities_data(1,i)>0 && isempty(find(cuac_data(1,:)==equities_data(1,i)))==0
        % stores column in equities data, cuac_data with that bidder and bidder number
        samebidder(end+1,1:3)=[i find(cuac_data(1,:)==equities_data(1,i)) equities_data(1,i)];
    end
end
disp(['There is ' num2str(size(samebidder,1)) ' bidders in auction data and both equities and CuAc data.'])

cuac_data_temp=cuac_data(2:end,samebidder(:,2));
cuac_data_temp=reshape(cuac_data_temp, size(cuac_data_temp,1)*size(cuac_data_temp,2),1);
disp(['Mean CuAc banks in all data: ' num2str(mean(cuac_data_temp(isnan(cuac_data_temp)==0)))])
disp(['St Dev CuAc banks in all data: ' num2str(std(cuac_data_temp(isnan(cuac_data_temp)==0)))])
mrr_data_temp=mrr_data(2:end,samebidder(:,2));
mrr_data_temp=reshape(mrr_data_temp, size(mrr_data_temp,1)*size(mrr_data_temp,2),1);
disp(['Mean MRR banks in all data: ' num2str(mean(mrr_data_temp(isnan(mrr_data_temp)==0)))])
disp(['St Dev MRR banks in all data: ' num2str(std(mrr_data_temp(isnan(mrr_data_temp)==0)))])
mrrcuac=cuac_data_temp./mrr_data_temp;
disp(['Mean CuAc/MRR banks in all data: ' num2str(mean(mrrcuac(isnan(mrrcuac)==0)))])
disp(['St Dev CuAc/MRR banks in all data: ' num2str(std(mrrcuac(isnan(mrrcuac)==0)))])

equit_data_temp=equities_data(2:end,samebidder(:,1));
equit_data_temp=reshape(equit_data_temp, size(equit_data_temp,1)*size(equit_data_temp,2),1);
disp(['Mean stock price banks in all data: ' num2str(mean(equit_data_temp(isnan(equit_data_temp)==0)))])
disp(['St Dev stock price banks in all data: ' num2str(std(equit_data_temp(isnan(equit_data_temp)==0)))])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% regression of marg values on cuac/mrr and equity price %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cuac_data_temp=cuac_data(2:end,samebidder(:,2));
mrr_data_temp=mrr_data(2:end,samebidder(:,2));
equit_data_temp=equities_data(2:end,samebidder(:,1));
mrrcuac=cuac_data_temp./mrr_data_temp;
deficiency_data_temp=deficiency_data(2:end,samebidder(:,2));

%construct matrix with all variables: [bidder number, margval, EONIA, deficiency, cuac, equit
%bidder_counter] - there is 21 bidders in both covariate and margval data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% if bids instead of marginal values to be used, set 'usebids'=1 from here %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eonia=agdata(:,13);
mv_cuac_equit=[];
counter=1; 
for i=1:size(samebidder,1)    
    mv_cuac_equit=[mv_cuac_equit; ones(auctions,1)*samebidder(i,3) marg_all(:,samebidder(i,3))-usebids*shade_all(:,samebidder(i,3)) eonia deficiency_data_temp(:,i) mrrcuac(:,i) equit_data_temp(:,i) counter*ones(auctions,1)];
    counter=counter+1;    
end

% create bidder fixed effects (8th-28th column) and time trend effects 
for i=1:size(samebidder,1)
    mv_cuac_equit((i-1)*auctions+1:(i-1)*auctions+auctions,end+1)=ones(auctions,1);
end
time=1:50;
time=repmat(time',size(samebidder,1),1);
% create time dummies (29th-78th column) & bidder fixed effects which
% change after auction 32.
bidder_fe=zeros(auctions*size(samebidder,1),2*size(samebidder,1));
for i=1:size(samebidder,1)
    bidder_fe((i-1)*auctions+1:i*auctions,(i-1)*2+1:(i-1)*2+2)=[ones(32,1) zeros(32,1); zeros(18,1) ones(18,1)];
end
for i=1:auctions
    mv_cuac_equit(:,end+1)=zeros(size(mv_cuac_equit,1),1);
    for j=i:auctions:size(mv_cuac_equit,1)        
        mv_cuac_equit(j,end)=1;
    end
end
    
% eliminate rows with NaN
mv_cuac_equit2=mv_cuac_equit(max(isnan(mv_cuac_equit'))'<1,:);
bidder_fe=bidder_fe(max(isnan(mv_cuac_equit'))'<1,:);
% elimanate lines with zero marginal values (not estimated there)
mv_cuac_equit2=mv_cuac_equit2(mv_cuac_equit2(:,2)>0,:);
bidder_fe=bidder_fe(mv_cuac_equit2(:,2)>0,:);
time=time(max(isnan(mv_cuac_equit'))'<1);
time=time(mv_cuac_equit2(:,2)>0);
% eliminate columns of only zeros (some fixed effect dummies)
mv_cuac_equit2=mv_cuac_equit2(:,max(mv_cuac_equit2)>0);
bidder_fe=bidder_fe(:,max(bidder_fe)>0);

%shift stock data in observation t, should have t+1 price:
temp=mv_cuac_equit2;
mv_cuac_equit2(1:end-1,4)=mv_cuac_equit2(2:end,4);
mv_cuac_equit2(end,:)=[];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% MAIN REGRESSIONS FOR TABLE 6 %%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% regress value on eonia, deficiency and stock price in t+1

%normal ols
ols=regstats(mv_cuac_equit2(:,2), [mv_cuac_equit2(:,[3 4 6])],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
%with bidder fixed effects (22nd bidder left out)
ols_fe=regstats(mv_cuac_equit2(:,2), [mv_cuac_equit2(:,[3 4 6 8:22]) ],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
%with time fixed effects (72nd time left out)
ols_timefe=regstats(mv_cuac_equit2(:,2), [mv_cuac_equit2(:,[4 6 24:72])],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
%with all fixed effects (22nd bidder left out and 72nd time left out)
ols_allfe=regstats(mv_cuac_equit2(:,2), [mv_cuac_equit2(:,[4 6 8:22 24:72])],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
%with bidder fixed effects allowed to vary after auction 32 (25th bidder left out and 75th time left out)
%ols_allfe=regstats(mv_cuac_equit2(:,2), [mv_cuac_equit2(:,3) bidder_fe(:,2:end)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});


%collect residuals:
resid=ols_fe.r;
resid_allfe=ols_allfe.r;

% assign turmoil dummy
turmoil=zeros(size(resid,1),1);
counter=1;
for i=1:size(resid,1)
    if max(mv_cuac_equit2(i,52:69))==1
        turmoil(i,1)=1;
    end
    resid(i,2)=counter;
    if counter<auctions        
        counter=counter+1;
    else
        counter=1;
    end
end
resid_allfe(:,2)=resid(:,2);

scatter(resid(:,2),resid(:,1))
scatter(resid(:,2),mv_cuac_equit2(:,2))
scatter(resid_allfe(:,2),mv_cuac_equit2(:,2))
%regress residuals on turmoil dummy (IS QUITE SIGNIFICANT!!!)
ols_resid=regstats(resid(:,1), turmoil,'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
ols_resid2=regstats(mv_cuac_equit2(:,2), turmoil,'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
ols_resid_allfe=regstats(resid_allfe(:,1), turmoil,'linear',{'yhat','beta','tstat','fstat','rsquare','r'});


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% separate regressions for each bidder  %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%first: variation in marginal values post turmoil for significantly
%affected bidders:
signif_in_covar=[];
for i=1:size(signif,1)
    signif_in_covar=[signif_in_covar; find(mv_cuac_equit2(:,1)==signif(i,1))]; %all observations of significantly affected bidders
end
temp=mv_cuac_equit2(signif_in_covar,:);
%isolate post-turmoil observations:
temp2=[];
for i=1:size(temp,1)
    if max(temp(i,end-18:end))>0
        temp2=[temp2; i];
    end
end
signif_in_covar_post=temp2;

% negative effect of deficiency and very low R^2
ols_signif_in_covar=regstats(mv_cuac_equit2(signif_in_covar,2), mv_cuac_equit2(signif_in_covar,3),'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
% R^2 increases but nothing spectacular. Let's try bidder-by-bidder
ols_signif_in_covar_post=regstats(mv_cuac_equit2(signif_in_covar_post,2), mv_cuac_equit2(signif_in_covar_post,3),'linear',{'yhat','beta','tstat','fstat','rsquare','r'});

signif_inter_covar_freq=[];
insignif_inter_covar_freq=[];
signif_inter_covar_infreq=[];
insignif_inter_covar_infreq=[];
for bidder=1:size(marg_all,2)
    if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
        % find if we have bidder covariates:
        bid_column=find(equities_data(1,:)==bidder);     
        
        %%% ADJUST THIS IF MORE COVARIATES WANTED! %%%
        covardata=equities_data(2:end,bid_column);  %%
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        if isempty(bid_column)==0 && sum(isnan(equities_data(marg_all(:,bidder)~=0,bid_column)))==0
            if observations_pre(1,bidder)>20 % frequent participant before turmoil            
                ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                    signif_inter_covar_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                else % insignificant turmoil effect
                    insignif_inter_covar_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                end
            else
                dummy_int=[dummy zeros(50,1)];
                ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                    signif_inter_covar_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                else % insignificant turmoil effect
                    insignif_inter_covar_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                end
            end  
        end
    end
end

% using current account balance and MRR covariates
% using bidder covariates
signif_inter_cuac_freq=[];
insignif_inter_cuac_freq=[];
signif_inter_cuac_infreq=[];
insignif_inter_cuac_infreq=[];
for bidder=1:size(marg_all,2)
    if observations(1,bidder)>2 && max(dummy(marg_all(:,bidder)~=0))~=min(dummy(marg_all(:,bidder)~=0)) %regression only if at least two observations
        % find if we have bidder covariates:
        bid_column_cuac=find(cuac_data(1,:)==bidder);
        covardata=cuac_data(2:end,bid_column_cuac);
        bid_column_mrr=find(mrr_data(1,:)==bidder);
        covardata2=mrr_data(2:end,bid_column_mrr);
        covardata=covardata./covardata2; %this covariate captures whether reserve requirements are met on the day of the auction
        if isempty(bid_column_cuac)==0 && sum(isnan(cuac_data(marg_all(:,bidder)~=0,bid_column_cuac)))==0
            if observations_pre(1,bidder)>20 % frequent participant before turmoil            
                ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                    signif_inter_cuac_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                else % insignificant turmoil effect
                    insignif_inter_cuac_freq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                end
            else
                dummy_int=[dummy zeros(50,1)];
                ols=regstats(marg_all(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                ols_norm=regstats(normalized_mv(marg_all(:,bidder)~=0,bidder), [dummy(marg_all(:,bidder)~=0) covardata(marg_all(:,bidder)~=0)],'linear',{'yhat','beta','tstat','fstat','rsquare','r'});
                if ols_norm.tstat.pval(2,1)<=0.05 % significant turmoil effect            
                    signif_inter_cuac_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                else % insignificant turmoil effect
                    insignif_inter_cuac_infreq(end+1,:)=[bidder observations(1,bidder) ols_norm.tstat.beta(2:3,1)' ols_norm.tstat.pval(2:3,1)'];
                end
            end  
        end
    end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%% plotting of results %%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%histograms of coefficients for significant and insignificant effect of
%turmoil
figure
hist(insignif(:,3)*100)
title('Histogram of insignificant coefficients on turmoil dummy')
xlabel('Change in Mean Marginal Value (in basis points)')

figure
hist(signif(:,3)*100)
title('Histogram of significant coefficients on turmoil dummy')
xlabel('Change in Mean Marginal Value (in basis points)')


% histograms of "frequency of participation" of bidders with significant and
% insignificant effect of turmoil
figure
hist(insignif(:,2))
title('Histogram of participation frequency of bidders with insignificant coefficients on turmoil dummy')
xlabel('# of Auctions in which a Bidder Participated')
axis([0 50 0 30])
figure
hist(signif(:,2))
xlabel('# of Auctions in which a Bidder Participated')
title('Histogram of participation frequency of bidders with significant coefficients on turmoil dummy')
axis([0 50 0 140])


% same as before but for turmoil effect bigger than median 
figure
hist(signif(signif(:,3)>median(signif(:,3)),2))
xlabel('# of Auctions in which a Bidder Participated')
title('Histogram of participation frequency of bidders with large coefficients on turmoil dummy')


% histograms of "frequency of participation" of bidders with significant and
% insignificant effect of turmoil conditional on frequent pre-turmoil
% participation
figure
hist(insignif_inter_freq(:,2))
title({'Histogram of participation frequency of bidders with insignificant coefficients on turmoil dummy'; 'conditional on frequent early participation'})
xlabel('# of Auctions in which a Bidder Participated')
axis([30 50 0 30])
figure
hist(signif_inter_freq(:,2))
title({'Histogram of participation frequency of bidders with significant coefficients on turmoil dummy'; 'conditional on frequent early participation'})
xlabel('# of Auctions in which a Bidder Participated')
axis([30 50 0 140])

% histograms of "frequency of participation" of bidders with significant and
% insignificant effect of turmoil conditional on infrequent pre-turmoil
% participation
figure
hist(insignif_inter_infreq(:,2))
title({'Histogram of participation frequency of bidders with insignificant coefficients on turmoil dummy'; 'conditional on infrequent early participation'})
xlabel('# of Auctions in which a Bidder Participated')
axis([0 50 0 30])
figure
hist(signif_inter_infreq(:,2))
title({'Histogram of participation frequency of bidders with significant coefficients on turmoil dummy'; 'conditional on infrequent early participation'})
xlabel('# of Auctions in which a Bidder Participated')
axis([0 50 0 40])

 %histogram of participation conditional on availability of current
 %account data:
 figure
 hist(meancuac(3,:))
 title({'Histogram of participation frequency conditional on current account data availability'})
xlabel('# of Auctions in which a Bidder Participated')
figure
hist(participation)
title({'Histogram of participation in MROs'})
xlabel('# of Auctions in which a Bidder Participated')

% Let's compute the expected utilities before and after turmoil - and by
% bidder group.
for i=1:size(exputmax,1)
    for j=1:size(exputmax,2)
        temp=exputmax{i,j};
        exput_mean(i,j)=mean(temp(isnan(temp)==0));
        exput_median(i,j)=median(temp(isnan(temp)==0));
        exput_max(i,j)=max(temp(isnan(temp)==0));
        exput_min(i,j)=min(temp(isnan(temp)==0));
        exput_std(i,j)=std(temp(isnan(temp)==0));
    end
end
disp(['Mean exp util before: ' num2str(mean(exput_mean(find(isinf(exput_mean(1:32,1))==0),1)))])        
disp(['Mean exp util after: ' num2str(mean(exput_mean(find(isinf(exput_mean(33:50,1))==0),1)))])        
disp(['Median exp util before: ' num2str(mean(exput_median(find(isinf(exput_median(1:32,1))==0),1)))])        
disp(['Median exp util after: ' num2str(mean(exput_median(find(isinf(exput_median(33:50,1))==0),1)))])       
 
% THESE ARE SOME OLDER PLOTS OF INTEREST RATES

% % subtract EONIA rate from the avg marginal value
% eonia=agdata(:,13);
% premium=allavgmarg-repmat(eonia,1,size(allavgmarg,2));
% premium_unw=allavgmarg_unw-repmat(eonia,1,size(allavgmarg,2));
% riskpremium=agdata(:,14)-agdata(:,13); %repo rate - eonia swap
% 
% %plot (repo rate - EONIA swap rate) difference
% figure(1)
% plot(riskpremium)
% title('Repo rate - EONIA difference')
% 
% %plot q-weighted avg marg value - EONIA difference
% figure(2)
% plot(premium(:,1))
% title('Quantity weighted avg marg value - EONIA difference')
% 
% %plot unweighted avg marg value - EONIA difference
% figure(3)
% plot(premium_unw(:,1))
% title('Unweighted avg marg value - EONIA difference')
% 
% %plot q-weighted bid rate
% figure(4)
% plot(agdata(:,8))
% title('Quantity weighted bid')
% 
% %plot q-weighted bid rate - EONIA difference
% figure(5)
% plot(agdata(:,8)-eonia)
% title('Quantity weighted bid - EONIA difference')
% 
% %plot both EONIA adjusted q-weighted bid and avg margval
% figure(6)
% plot(agdata(:,8)-eonia,'r')
% hold on
% plot(premium(:,1))
% legend('Q-weighted bid', 'Q-weighted marginal value')
% title('Quantity weighted bid and marginal value - EONIA difference')
