function[estim,bidsteps,bidstepscum,pgrid,invbidfunc,spanauc,span]=dataread(data,auctiongroup,auctiongroupsize,pmax)

%'data' variable contains data on bids. 1st column is just ID generated in db
%program. 2nd col: auction_id, 3rd c: submitter, 4th marg quant, 5th
%c: yield bid (decreasing), 6th: marginal q-bid, 7th: actual bidder, 8th: nothing, 9th:
%preannounced supply, 10th: country identifier
%Parameter 'Auctiongroup' denotes which group of 'auctiongroupsize'
%auctions to return. if auctiongroup=0, use all data.

%These global variables are accessed in the 'resample.m' routine.
global pstep Group1 Group2

%this routine figures out the groups of bidders in 'data'
if isempty(Group1)==1
    maxbidder=max(max(data(:,3)),max(data(:,7)));
    Group1=[];
    Group2=[];  
    for j=1:maxbidder
        if max(data(:,3)==j)==1
            Group1(1,end+1)=j; %Submitters             
        end
    end     
end

% price grid step: 1 basis point
%pstep=0.01;

%delete the auctions that are not comparable: 20070053, 20070090, 20070096
data=data(data(:,2)~=20070053 & data(:,2)~=20070090 & data(:,2)~=20070096,:);

%data(:,5)=data(:,5)*10000; %convert to prices...
datsize=size(data);

%Normalize q-demands at each step

data(:,datsize(1,2)+1)=data(:,4)./data(:,9); %11th column: marginal demand

%create span variable, which stores span of individual auctions in "data"
auctions=1;
span=[data(1,2) 1 0];
for i=2:datsize(1,1)
    %count unique auction IDs
    if data(i-1,2)~=data(i,2) %new auction        
        auctions=auctions+1;
        if auctions>1
            span(auctions,1)=data(i,2);
            span(auctions,2)=i; %beginning of an auction in estim
            span(auctions-1,3)=i-1; %end of an auction
        else
            span(auctions,1)=data(i-1,2);
            span(auctions,2)=1;
        end
    end
end    
%last auction:
span(auctions,:)=[data(i,2) span(auctions-1,3)+1 i];

%use variable auctiongroup to read the relevant bids, if auctiongroup=0,
%use all data
if auctiongroup~=0
    data=data(span(auctiongroupsize*(auctiongroup-1)+1,2):span(auctiongroupsize*auctiongroup,3),:);    
end

datsize=size(data);

%Now construct corresponding inverse demands and cumulative demands

%count number of bidfunctions
nbidfuns=1;
data(1,datsize(1,2)+1)=data(1,datsize(1,2)); %the extra column stores cumulative demand
datsize=size(data);
spanauc=[data(1,2) 1 0]; %stores span of auctions in inverse bids

for j=2:datsize(1,1)
   if data(j,7)==data(j-1,7)
       %['Same Bidder']
       data(j,datsize(1,2))=data(j,datsize(1,2)-1)+data(j-1,datsize(1,2));
   else 
       %['New bidder']
       nbidfuns=nbidfuns+1;
       data(j,datsize(1,2))=data(j,datsize(1,2)-1);
   end
   if data(j,2)~=data(j-1,2)
       %['New auction']
      spanauc(end,3)=nbidfuns-1;
      spanauc(end+1,1:3)=[data(j,2) nbidfuns 0];
   end
end
%last auction
spanauc(end,3)=nbidfuns;
        
  %create price grid in basis points
  
  pmin=min(data(:,5))-0.05;
  if exist('pmax','var')==0
    pmax=max(data(:,5))+0.05;
  end
  
  pgrid=[];
  pgrid=pmin:pstep:pmax;
  %pgrid=round(pmin*1000):round(pstep*1000):round(pmax*1000)./1000;
  pgridsize=size(pgrid);
  
  invbidfunc=zeros(nbidfuns,pgridsize(1,2));
  
%set a reference variable referring to the line in data (bidpoint) and initiate a variable to which to store number of steps
    k=0;
    bidsteps=zeros(nbidfuns,1);
    
% Construct a variable which cummulatively sums the steps in bidfunctions - this will allow for easier addressing of prices 
% when estimating the derivative
    bidstepscum=zeros(nbidfuns,1);
    
for q=1:nbidfuns
    %counts line in data
    k=k+1;
    %counts steps in current bidfunction
    j=1;
        for m=pgridsize(1,2):-1:1
            %first check if the current point on grid is less or equal to p bid on current line k (i.e., higher yield than the bid), if yes then enter current cumulative quantity bid                        
            if data(k,5)+pstep/1000>=pgrid(1,m), invbidfunc(q,m)=data(k,end); end
            
            if k<datsize(1,1)
            %if next bidpoint is still by same bidder, check whether it is higher than the next point on the grid, if yes take next one
                if data(k,2)==data(k+1,2) && data(k,7)==data(k+1,7), if data(k+1,5)+pstep/1000>=pgrid(1,max(m-1,1)), k=k+1; j=j+1; end 
                else
            %check if the next bidpoint is still by the same bidder, if not, break the for loop to get the next bidcurve
   
                    if m==1, bidsteps(q,1)=j; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+j; break, end
                end               
            else bidsteps(q,1)=j; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+j;
            end          
            
        end
end
% for q=1:nbidfuns
%     step=1;
%     if q==1
%         beginstep=0;
%     else
%         beginstep=bidstepscum(q-1,1);
%     end
%     for m=pgridsize(1,2):-1:1
%          %first check if the current point on grid is less or equal to p bid on current line k (i.e., higher yield than the bid), if yes then enter current cumulative quantity bid                        
%          if data(beginstep+step,5)+pstep/1000>=pgrid(1,m), invbidfunc(q,m)=data(beginstep+step,end); end         
%          if beginstep+step<datsize(1,1)            
%              %if next bidpoint is still by same bidder, check whether it is
%              %higher than the next point on the grid, if yes take next one
%             if data(beginstep+step,2)==data(beginstep+step+1,2) && data(beginstep+step,7)==data(beginstep+step+1,7)
%                 if data(beginstep+step+1,5)+pstep/1000>=pgrid(1,m), invbidfunc(q,m)=data(beginstep+step+1,end); step=step+1; end
%                 %if data(beginstep+step+1,5)>=pgrid(1,max(m-1,1)), step=step+1; end 
%             else
%                 %check if the next bidpoint is still by the same bidder, if
%                 %not, break the for loop to get the next bidcurve
%                 if m==1, bidsteps(q,1)=step; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+step; step=1; break, end
%             end
%          else
%              bidsteps(q,1)=step; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+step;
%          end
%     end
%    
% end
            

estim(:,5)=data(:,5);  %price bid
estim(:,7)=data(:,end); %cumul q-bid (should be 12th column)
estim(:,6)=data(:,4)./data(:,9);
estim(:,3)=data(:,9);  %Q for sale
estim(:,2)=data(:,2);  %auction ID
estim(:,4)=data(:,7);  %Bidder
estim(:,8)=data(:,10); %country identifier
estim(:,1)=data(:,3);  %Bidder         
