function []=ecb_main(b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,b11,b12,b13)

%This is the main file for testing for marginal value estimation in ECB auctions. 

%Example: ecb_main(500,3000,3,0,1,1,5,600,25,1,1,5,0)

% b1 is # of bootstrap draws
% b2 is # of resampling draws
% b3 is which model to use. 1= v is continuous in q; 2= v is a step function
%   with steps ending at submitted quantities; 3= v is cnts
%   in q up to the last step at which the price FOC is used to identify v
% b4 =1 if send email when job done which contains ip address of computer
%   where job was executed.
% b5 oversampling parameter for positive bids rather than zero bids (=1 if no
%   oversampling)
% b6 (=1) random assignement to groups at the start of iterating asymmetric model
% b7  p-value (in PERCENT) of dummy coefficient below which a bidder will be deemed ''in
% trouble''
% b8 cutoff (in BASIS points) above which to deem an estimate of marginal value as craze and
%    replace by bid + premium
% b9 premium (in BASIS points) for trimming crazy marginal value outliers - this is used mainly for
%    efficiency calculations - the original mv estimates stored and unaffected
% b10 =1 if analysis of MROs (default), =0 if LTROs
% b11 =1 if asymmetric model (with at most 50 group selection loops - can
%    be changed below together with the convergence criterion

% bidders will be assigned to Group2 when there is a significant shift in
% their mean quantity-weighted marginal valuation post-turmoil
% b12 integer = convergence criterion for asymmetric model change in the 
%       size of the group and switching identities that define 
%       convergence of bidder groups
% b13 =1 if quantile regression to be used to classify bidders (default is
% OLS)
%clear;


starttime=now;
global model pgrid pstep resamplingdraws bidstepscum bidsteps estim bootdraws nbidfun invbidboot oversample supplynoise auctions aucgroupsize Group1 Group2 mro

if exist('b10','var')==0 %select if we analyze MROs or LTROs
    mro=1;
else
    mro=b10;
end

if exist('b4','var')==0 %running locally
    cd /home/jakub/Matlab/Nuno
else %running on linux cluster
    if b4==1
        cd /tmp/jkastl
    else
        cd /home/jakub/Matlab/Nuno
    end
end

if exist('b12','var')==0
    convergencecriterion=5; %change in the size of the group and switching identities that define convergence of bidder groups
else
    convergencecriterion=b12;
end

%pvalue=0.03;    % p-value of dummy coefficient below which a bidder will be deemed ''in trouble''
asymmetricloops=3; %maximum # of times to iterate the group derivation
%convergencecriterion=5; %change in the size of the group and switching identities that define convergence of bidder groups
pstep=0.005; % step should be at least one half of a basis point=0.005 (so that we can estimate the probability of
             % clearing price begin strictly between the two steps)
supplynoise=0; %if small random noise to supply should be added (improves precision)
aucgroupsize=1; %how many auctions in an auctiongroup (in total we have 50 auctions)
%cutoff=b7; %5.5  % above what percentage rate to trim marginal values - used to eliminate outliers (adjusted margval is saved separately as margval_adj)

if mro==1
    load('ecb_data.mat','data')
    % load auction level aggregate data & supply deviation
    % agdata: [1: auctionID 2: maturity(days) 3:(ignore) 4: minim_bid_rate (policy) 5: clearing_rate
    % 6: rationing_coeff 7: actual_allotment 8: wght_avg_rate 9: total_demand
    % 10: # of actual_bidders  11: minim_bid_rate across all bids in an auction (same as 4th col) 
    % 12: max_bid 13: EONIA 14: EUREPO 15: EURIBOR]
    % supply: [1: auctionID 2: actual_allotment 3: announced_benchmark 
    %  4: devation_from_benchmark] 5: deviation_as_percent_of_announced]
    load('nuno.mat','agdata','supply')  
    turmoilcutoff=32;
else
    if b4==0 %running locally
        load('/home/jakub/Matlab/Nuno/data_ltro.mat','data_ltro_numbers','agdata_ltro')
    else
        load('data_ltro.mat','data_ltro_numbers','agdata_ltro')
    end
    data=data_ltro_numbers;
    agdata=agdata_ltro;
    turmoilcutoff=11;
end

auctions=size(agdata,1); 

if exist('b13','var')==0
    qregression=0;   % if allowing for asymmetric model: first estimate symmetric resampling, get troubled banks,                   % then re-estimate treating troubled banks asymmetrically           
else
    qregression=b13;
end

if exist('b11','var')==0
   asymmetric=1;   % if allowing for asymmetric model: first estimate symmetric resampling, get troubled banks,
                   % then re-estimate treating troubled banks asymmetrically           
else
    asymmetric=b11;
end


if exist('b9','var')==0
    premium=0.25; % substitute trimmed marg values by bid+this premium
else
    premium=0.01*b9; 
end
if exist('b8','var')==0
    cutoff=5.5;  % above what percentage rate to trim marginal values - used to eliminate outliers (adjusted margval is saved separately as margval_adj)
                 % the maximum value of EURIBOR (unsecured rate) over the
                 % sample period is 4.3150
else
    cutoff=0.01*b8; 
end
if exist('b7','var')==0
    pvalue=0.05;  %  p-value of dummy coefficient below which a bidder will be deemed ''in trouble''
else
    pvalue=0.01*b7; 
end
if exist('b6','var')==0
    randomstart=1;  % initial asignement into groups is random, otherwise bidders treated symmetrically in the 1st iteration    
else
    randomstart=b6;
end
if exist('b5','var')==0
    oversample=1; %no oversampling is default
else
    oversample=b5;
end
if exist('b4','var')==0
    sendemail=0; %no email is default
else
    sendemail=b4;
end
if exist('b3','var')==0
    model=3; %step function model is default (effects last step mostly)
else
    model=b3;
end
if exist('b2','var')==0
    resamplingdraws=3000; 
else
    resamplingdraws=b2;
end
if exist('b1','var')==0
    bootdraws=5;
else
    bootdraws=b1;
end
timetemp=rem(now,1);
rand('twister',sum(100*clock));
randstate=rand('twister');

if mro==1
    disp('Analyzing MROs.....')
else
    disp('Analyzing LTROs.....')
end
disp(['Will use ' int2str(resamplingdraws) ' resamples when getting clearing price distribution'])
disp(['In total we want ' int2str(bootdraws) ' bootstrap draws for std errors.'])   
disp(['We will pool together ' int2str(aucgroupsize) ' auctions for resampling.']) 
if asymmetric==0
    disp('Using symmetric model.')
else
    if randomstart==1 
        disp(['Initial assignment into groups is random.'])
    else
        disp(['Initial iteration assumes symmetry.'])
    end
    disp(['Convergence criterion: (change in size and identities switches) :' num2str(convergencecriterion)])
end
if qregression~=1
    disp(['Using OLS for classification of bidders.'])
else
    disp(['Using Median regression for classification of bidders.'])
end
disp(['For adjustment of outliers: cutoff/premium: ' num2str(cutoff) ' ' num2str(premium)]) 

disp([' '])
disp(['*************************************************************************************** '])
disp([' '])
clear b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12
%savefile = ['ecb_' int2str(bootdraws) '_' int2str(resamplingdraws) '_' num2str(oversample) '.mat'];
           
%assign randomly bidders to groups as a test of convergence algorithm
if randomstart==1 
   Group1=[];
   [estim,bidsteps,bidstepscum,pgrid,invbidfunc,span]=dataread(data,1,1); %this gets all identities into Group1 matrix
   temp=Group1;
   Group1=[];
   for i=1:size(temp,2)
       if rand>0.5 % assign to Group2
           Group2=[Group2 temp(1,i)];
       else
           Group1=[Group1 temp(1,i)];
       end
   end
end           
convergence=0;
meanp=[];
stddevp=[];

for asymloop=1:asymmetricloops % for-loop when doing two iterations with asymmetric model
    
%Initialize marginal values variable
margvalall=mat2cell(zeros(auctions/aucgroupsize,bootdraws),ones(auctions/aucgroupsize,1),ones(1,bootdraws));   
    
for auctiongroup=1:auctions/aucgroupsize %we have 50 auctions - which gives 10 auctiongroups of 5 auctions each. Use auctiongroup=0 if all auctions should be used
  disp(['working on: ---------auctiongroup:   '  num2str(auctiongroup)]) % ' & ' num2str(boot) ])
 %read the data
 if auctiongroup~=0 %read just subset of auctions
    [estim,bidsteps,bidstepscum,pgrid,invbidfunc,span]=dataread(data,auctiongroup,aucgroupsize); 
    nbidfun=size(invbidfunc);
    %To plot a sample of a bid in auctiongroup 1: (in case only
    %one 'bootdraw')
    if auctiongroup==1 && bootdraws==1
        figure(1)
        plot(invbidfunc(1,:),pgrid(1,:),'-')
        legend('Bid Curve')
        xlabel('Quantity Share demanded')
        ylabel('Yield (Bid)')
        title('Bidding Behavior')
    end

 else %read all at once - this is for getting summary statistics mainly, not for actual estimation
     %auctiongroup=1;      
     [estim_all,bidsteps_all,bidstepscum_all,pgrid_all,invbidfunc_all,span]=dataread(data,0,aucgroupsize);
     nbidfun=size(invbidfunc_all);
 end

if asymmetric==1 && asymloop<asymmetricloops && convergence==0  % when estimating asymmetric model, we don't need all 
                                        % bootstrapdraws during in
                                        % iterations before convergence
    bootdraws_loop=1;
else
    bootdraws_loop=bootdraws;
end

for boot=1:bootdraws_loop %this is used for bootstrapping std errors

    %Create a "bootstrap sample" of 'invbidfunc'
    if boot==1
        invbidboot=invbidfunc; %First bootstrap sample is the original sample
    else
        invbidboot=bootsample(invbidfunc); %Create bootstrap sample for this auctiongroup
    end

    margvalall{auctiongroup,boot}=zeros(size(invbidfunc,1),max(bidsteps(:,1)));  %Initialize variable
    
    if mro==1 % resample also the supply: different distrib before and after turmoil
        if auctiongroup<=32
            ressupdist=resample(boot,supply(1:32,5)); %Obtain a distribution of residual supplies
        else
            ressupdist=resample(boot,supply(33:50,5));
        end
    else
        ressupdist=resample(boot); %no supply distribution to resample from in LTROs
    end
            
            

    for bidder=1:size(invbidfunc,1)
        [psort,pdistr,range,m1,s1]=pricedist(bidder,invbidfunc,ressupdist);
        if bootdraws_loop==bootdraws && boot==1 %after convergence or end of loop
            meanp(auctiongroup,estim(bidstepscum(bidder,1),4))=m1; %record mean and st dev of p-dist of each bidder
            stddevp(auctiongroup,estim(bidstepscum(bidder,1),4))=s1;
        end

        %discriminatory auction (needs function margdiscr)
        [margvalall{auctiongroup,boot}(bidder,:)]=margdiscr(bidder,psort,bidsteps,pdistr,range);

        %For robustness checks: use this part to impose nonincreasing marginal values by brute force
        %if step<bidsteps{1,auctiongroup}(bidder,1)
        %    if margvalall{auctiongroup,boot}(bidder,step+1)>margvalall{auctiongroup,boot}(bidder,step)
        %      margvalall{auctiongroup,boot}(bidder,step+1)=margvalall{auctiongroup,boot}(bidder,step); %This uses the previous value as upper bound
        %    end
        %end

        %end

        %Get the expected utility
        [exputmin{auctiongroup,boot}(bidder,1),exputmax{auctiongroup,boot}(bidder,1)]=exputil_da(bidder,margvalall{auctiongroup,boot}(bidder,:),psort,bidsteps,bidstepscum,estim);

    end %biddertemp finishes
    if sendemail==1 % make sure file timestamp gets updated once in 24 hours
        if timetemp>rem(now,1) && timetemp-rem(now,1)<0.1
            ! touch /tmp/jkastl/*.*
            ! touch /tmp/jkastl
            timetemp=rem(now,1);
        end
    end
    clear ressupuninf ressupinf
end %boot finishes

if mro==1
    savefile2=['ecb_main_mro_' int2str(auctiongroup) '_M' num2str(model) '_B' int2str(bootdraws) '_'  int2str(round(now))  '.mat'];
else
    savefile2=['ecb_main_ltro_' int2str(auctiongroup) '_M' num2str(model) '_B' int2str(bootdraws) '_'  int2str(round(now))  '.mat'];
end
if mod(auctiongroup,25)==0
    currenttime=now;    
    save(savefile2)
end

end %auctiongroup finishes

%Routine which figures two groups for asymmetric model at the end of 1st iteration
if asymmetric==1 && convergence==0
   if asymloop==1
       group1{1,1}=Group1;
       group2{1,1}=Group2;
   end
   [group1{asymloop+1,1},group2{asymloop+1,1},signif,insignif]=asigngroups(margvalall,data,Group1,Group2,cutoff,premium,pvalue,mro,qregression);
   if asymloop<asymmetricloops
    Group1=group1{asymloop+1,1};
    Group2=group2{asymloop+1,1};
   end
   %Determine if convergence of groups obtained in current iteration
   if abs(size(group1{asymloop+1,1},2)-size(group1{asymloop,1},2))<=convergencecriterion %sizes of groups do not fluctuate
       identchanges=0;
       for temp=1:size(group1{asymloop,1},2)
           if all(group1{asymloop+1,1}~=group1{asymloop,1}(1,temp))
               identchanges=identchanges+1; %identity dropped out
           end           
       end
       if size(group1{asymloop,1},2)<size(group1{asymloop+1,1},2) %identities added
           identchanges=identchanges-size(group1{asymloop,1},2)+size(group1{asymloop+1,1},2);
       end                  
       if identchanges<=convergencecriterion %identities do not fluctuate
           convergence=1;    
           disp(['Convergence of groups achieved in iteration: ' num2str(asymloop)])
       else
           disp([num2str(identchanges) ' identities switch groups. No convergence yet.'])
       end
   else
       disp(['Change in size of group 1: ' num2str(abs(size(group1{asymloop+1,1},2)-size(group1{asymloop,1},2))) ' No convergence yet.'])
   end
   disp(['Finished ' num2str(asymloop) ' iterations! '])
   disp(['Size of Healthy Group1: ' num2str(size(Group1,2))])
   disp(['Size of Bad Group2: ' num2str(size(Group2,2))])   
end
save(savefile2)
if convergence==1 && boot>1, break, end %break asymmetric for loop if converged and bootstrap loop is done as everything is finished now
end % asymmetric model for-loop finishes

finishtime=now;
disp(datestr(starttime))
disp(datestr(finishtime))

% Adjust marginal values: kill outliers above cutoff (3rd argument) by replacing them with
% bid + fixed premium (4th argument is `premium`), and make them strictly
% decreasing by at least `pstep` per step

[margvalall_adj]=margvaladjust(margvalall,data,cutoff,premium);

%unadjusted marg val:
[effi,effSE,grossuref,allocdummy]=efficiency(margvalall,data);
[effirnd,effrndSE,percentcovered,percent_SE]=efficiency_rnd(margvalall,data,grossuref);


%Evaluate efficiency in individual auctions
[effi_adj,effSE_adj,grossuref_adj,allocdummy_adj]=efficiency(margvalall_adj,data,1);

% Compute efficiency relative to the random mechanism and what percentage
% of efficient-random surplus distance the mechanism achieves
[effirnd_adj,effrndSE_adj,percentcovered_adj,percent_SE_adj]=efficiency_rnd(margvalall_adj,data,grossuref_adj);

% Compute quantity-weighted and unweighted averages of marginal values by
% bidder and by auctions
[allavgmarg,allavgmargstd,avgmarg,allavgmarg_unw,allavgmargstd_unw,avgmarg_unw]=avgmargval(margvalall_adj,data);


% Obtain which auctions and on which lines in `invbidfunc' and
% `margvalall' in those auctions a bidder identity participates
[bidaddress, frequentbidders, bidderfrequency]=findbidaddress(data);

% Now obtain a matrix of quantity-weighted marginal values by large
% bidders:
marg_all=zeros(auctions,size(bidaddress,1));
marg_all_unw=zeros(auctions,size(bidaddress,1));
for bidder=1:size(bidaddress,1)
    if bidaddress{bidder,1}(1,3)>0 % few identities never appear in the sample
        for j=1:size(bidaddress{bidder,1},1)
           marg_all(bidaddress{bidder,1}(j,1),bidder)=avgmarg{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
           marg_all_unw(bidaddress{bidder,1}(j,1),bidder)=avgmarg_unw{bidaddress{bidder,1}(j,1),1}(bidaddress{bidder,1}(j,2),1);
        end
    end
end

%create stata dataset for bidders [Marg val, auction, eonia, eurepo, euribor]:
%agdata=[];
%load('nuno.mat','agdata')
eonia=agdata(:,13);
stata=marg_all; 
%stata=marg_all-repmat(eonia,1,size(marg_all,2)).*(marg_all~=0); %%normalized marg val by eonia
stata(:,end+1)=1:1:auctions;
stata(:,end+1)=eonia;
stata(:,end+1)=agdata(:,14); % repo: highest liquid collateral (secured)
stata(:,end+1)=agdata(:,15); % euribor: unsecured rate
if mro==1
    savefile=['values_mro_' int2str(round(now)) '.txt'];
else
    savefile=['values_ltro_' int2str(round(now)) '.txt'];
end
    
save(savefile,'stata','-ASCII','-tabs')
clear stata

if mro==1
    savefile=['effallocdummy_mro_' int2str(round(now)) '.mat'];
else
    savefile=['effallocdummy_ltro_' int2str(round(now)) '.mat'];
end
save(savefile,'effi','effSE','grossuref','effirnd','effrndSE','percentcovered','percent_SE','effirnd_adj','effrndSE_adj','percentcovered_adj','percent_SE_adj','effi_adj','effSE_adj','marg_all','marg_all_unw','allocdummy_adj','allocdummy','grossuref_adj','allavgmarg','allavgmarg_unw','margvalall','margvalall_adj')

save(savefile2)

if bootdraws==1 % do not want plotting if running on cluster
%Plot efficiency
figure
plot(effi_adj)
hold on
plot(effi_adj-1.96*effSE_adj,'--r')
hold on
plot(ones(1,8)*turmoilcutoff, 0.65:0.05:1,'-.')
plot(effi_adj+1.96*effSE_adj,'--r')
axis([ 0 auctions+1 0.65 1])
legend('Efficiency (Achieved Surplus / Efficient Surplus)','95% confidence interval', 'Turmoil','Location','SouthWest')
xlabel('Auction')
ylabel('Efficiency (Achieved Surplus / Efficient Surplus)')
title('Efficiency of Actual Auctions')

%Plot efficiency
figure
plot(effirnd_adj)
hold on
plot(effirnd_adj-1.96*effrndSE_adj,'--r')
hold on
plot(ones(1,10)*turmoilcutoff, 0.65:0.05:1.1,'-.')
plot(effirnd_adj+1.96*effrndSE_adj,'--r')
axis([ 0 auctions+1 0.85 1.1])
legend('Performance (Achieved Surplus / Surplus from Random Alloc)','95% confidence interval', 'Turmoil','Location','SouthWest')
xlabel('Auction')
ylabel('Performance (Achieved Surplus / Surplus from Random Alloc)')
title('Performance of Actual Auctions')

%Plot avg marginal values (SHOULD ALSO NORMALIZE BY EONIA!)
figure
plot(allavgmarg(:,1)-eonia)
hold on
plot(allavgmarg(:,1)-eonia-1.96*std((allavgmargstd-repmat(eonia,1,size(allavgmargstd,2)))')','--r')
hold on
plot(allavgmarg(:,1)-eonia+1.96*std((allavgmargstd-repmat(eonia,1,size(allavgmargstd,2)))')','--r')
plot(ones(1,12)*turmoilcutoff, -0.1:0.1:1,'-.')
axis([ 0 auctions -0.1 1])
legend('Average marginal values - EONIA','95% confidence interval','','Turmoil','Location','NorthWest')
xlabel('Auction')
ylabel('Quantity-weighted average of marginal values - EONIA')
title('Average Marginal Values - EONIA')

end

%Renew time stamps on files so that stanford unix servers do not delete them
%! /tmp/jkastl/stampweek.sh

%Everything is done: send email with IP report.
if sendemail==1
! ifconfig | grep 'inet addr' > /tmp/jkastl/ipreport.txt
! ps aux | grep MATLAB >> /tmp/jkastl/ipreport.txt
! cat /tmp/jkastl/ipreport.txt | mail -s 'Job done!' jkastl
end

