function [effirnd,effrndSE,percentcovered,percent_SE,percentcov,actgrossur,grossurrnd]=efficiency_rnd(margvalall,data,grossuref)
%This file evaluates efficiency using the estimated marginal values relative to random allocation
%in auctions between begin_auc and end_auc.

global auctions aucgroupsize bootdraws pstep
N=auctions/aucgroupsize;

effrndSE=zeros(N,aucgroupsize);
effirnd=zeros(N,aucgroupsize);
effdiff_mean=zeros(N,aucgroupsize);
rat=zeros(N,aucgroupsize);

for auctiongroup=1:N   
%Now we need to figure out who won how much...
[estim,bidsteps,bidstepscum,pgrid,invbidfunc,spanauc,span]=dataread(data,auctiongroup,aucgroupsize); 
pgridsize=size(pgrid);
datasize=size(invbidfunc);
    for auction=1:aucgroupsize    
        %first find the market clearing price on the grid:
        p=find(sum(invbidfunc(spanauc(auction,2):spanauc(auction,3),:))>=1,1,'last');
        pclearauc=pgrid(1,p);

        %determine AD above market clearing price (clear price + 1) +
        %noncompetitive bid
        if p+1<=size(invbidfunc,2)
            ADabove(auctiongroup,auction)=sum(invbidfunc(spanauc(auction,2):spanauc(auction,3),p+1));
        else
            ADabove(auctiongroup,auction)=0;
        end

        %Now determine marginal AD at market clearing price
        ADmarg(auctiongroup,auction)=sum(invbidfunc(spanauc(auction,2):spanauc(auction,3),p))-ADabove(auctiongroup,auction);

        %Rationing coefficient
        if ADmarg(auctiongroup,auction)>0 
            rat(auctiongroup,auction)=max((1-ADabove(auctiongroup,auction))/ADmarg(auctiongroup,auction),0);
        else
            rat(auctiongroup,auction)=1;
        end

        %Now construct same matrix as margvalall, which instead of marginal
        %valuations will have how much quantity that bidder got
        alloc=zeros(size(margvalall{auctiongroup,1}));

        if auction==1
           begin=1;
        else
           begin=bidstepscum(spanauc(auction-1,3),1)+1;
        end

        bidder=spanauc(auction,2);
        step=1;
        for i=begin:bidstepscum(spanauc(auction,3),1) %Cycles through all bids submitted in an auction
            if estim(i,5)+pstep/1000>pclearauc && estim(i,5)-pstep/1000>pclearauc %let's give full requests to bids above market clearing price       
               if step==1
                   alloc(bidder,step)=estim(i,7); 
                   step=step+1;
               else
                   alloc(bidder,step)=estim(i,7)-estim(i-1,7);
                   step=step+1;
               end
            end
            if estim(i,5)+pstep/1000>pclearauc && estim(i,5)-pstep/1000<pclearauc %let's adjust rationed bidders
                if step==1
                     alloc(bidder,step)=estim(i,7)*rat(auctiongroup,auction);
                     step=step+1;
                else
                    alloc(bidder,step)=(estim(i,7)-estim(i-1,7))*rat(auctiongroup,auction);
                    step=step+1;
                end
            end

            if i==bidstepscum(bidder,1); %switch to next bidder
                bidder=bidder+1;  
                step=1;
            end
        end
    if sum(sum(alloc))>1+1e-5, disp(['Alloc problem: ' sum(sum(alloc))]), pause, end
        clear help

        %Now let's compute the actual gross surplus from the current auction - for each
        %marginal valuation matrix
        for boot=1:bootdraws    
            %let's adjust margvalall not to have any NaN entries
%             for i=1:size(margvalall{auctiongroup,boot},1)
%                 for j=1:size(margvalall{auctiongroup,boot},2)
%                     
%                 end
%             end
            
            help=margvalall{auctiongroup,boot}(spanauc(auction,2):spanauc(auction,3),:).*alloc(spanauc(auction,2):spanauc(auction,3),:);
            help=sum(help(isnan(help)==0 & isfinite(help)==1));
            actgrossur{auctiongroup,boot}(auction,1)=help; % surplus per 1 percent of supply sold
        end

        %Now let us get the surplus if we were to allocate
        %units randomly for this auction (for each bootdraw, with the same random alloc)
        
        %Determine the random order of bidders:
        biddraws=spanauc(auction,3)-spanauc(auction,2)+1; %size(margvalall{auctiongroup,1},1);
        rnd_order=spanauc(auction,2)-1+unidrnd(biddraws,biddraws,1); % bidders could repeat in this draw
%%
        agdem=max(invbidfunc(rnd_order(1,:))); % take maximum demanded by first random bidder and start adding up
        %Construct also the same matrix as margvalall, which instead of marginal
        %valuations will have how much quantity that bidder got in the random alloc
        allocrnd=zeros(size(margvalall{auctiongroup,1}));
        for step=1:bidsteps(rnd_order(1,1),1)
            if step<bidsteps(rnd_order(1,1),1) && step==1
                if rnd_order(1,1)>1
                    allocrnd(rnd_order(1,1),step)=estim(bidstepscum(rnd_order(1,1)-1,1)+step+1,7);
                else
                    allocrnd(rnd_order(1,1),step)=estim(step+1,7);
                end
            else
                if step<bidsteps(rnd_order(1,1),1)
                    if rnd_order(1,1)>1 
                        allocrnd(rnd_order(1,1),step)=estim(bidstepscum(rnd_order(1,1)-1,1)+step+1,7)-estim(bidstepscum(rnd_order(1,1)-1,1)+step,7);
                    else
                        allocrnd(rnd_order(1,1),step)=estim(step+1,7)-estim(step,7);
                    end
                else
                    if step==1
                        if rnd_order(1,1)>1 
                            allocrnd(rnd_order(1,1),step)=estim(bidstepscum(rnd_order(1,1)-1,1)+step,7);
                        else
                            allocrnd(rnd_order(1,1),step)=estim(step,7);
                        end                        
                    end
                end
            end
        end
        
        for i=2:biddraws  
            while any(rnd_order(1:i-1,1)==rnd_order(i,1))==1 && agdem<1.1 %make sure sampling w/o replacement until ag supply depleted
               rnd_order(i,1)=spanauc(auction,2)-1+unidrnd(biddraws,1,1);               
            end
            if any(rnd_order(1:i-1,1)==rnd_order(i,1))==0 %if indeed sampling w/o replacement                              
               for step=1:bidsteps(rnd_order(i,1),1)
                   if step<bidsteps(rnd_order(i,1),1) && step==1
                       if rnd_order(i,1)>1
                           if estim(bidstepscum(rnd_order(i,1)-1,1)+step+1,7)+agdem<=1
                               allocrnd(rnd_order(i,1),step)=estim(bidstepscum(rnd_order(i,1)-1,1)+step+1,7);  
                               agdem=agdem+allocrnd(rnd_order(i,1),step);
                           else
                               allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                               agdem=agdem+allocrnd(rnd_order(i,1),step);
                               break
                           end
                       else
                           if estim(step+1,7)+agdem<=1
                               allocrnd(rnd_order(i,1),step)=estim(step+1,7);
                               agdem=agdem+allocrnd(rnd_order(i,1),step);
                           else
                               allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                               agdem=agdem+allocrnd(rnd_order(i,1),step);
                               break
                           end
                       end
                   else
                       if step<bidsteps(rnd_order(i,1),1)
                           if rnd_order(i,1)>1
                               if estim(bidstepscum(rnd_order(i,1)-1,1)+step+1,7)-estim(bidstepscum(rnd_order(i,1)-1,1)+step,7)+agdem<=1
                                   allocrnd(rnd_order(i,1),step)=estim(bidstepscum(rnd_order(i,1)-1,1)+step+1,7)-estim(bidstepscum(rnd_order(i,1)-1,1)+step,7);
                                   agdem=agdem+allocrnd(rnd_order(i,1),step);
                               else
                                   allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                                   agdem=agdem+allocrnd(rnd_order(i,1),step);
                                   break
                               end
                           else
                               if estim(step+2,7)-estim(step+1,7)+agdem<=1
                                   allocrnd(rnd_order(i,1),step)=estim(step+1,7)-estim(step,7);
                                   agdem=agdem+allocrnd(rnd_order(i,1),step);
                               else
                                   allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                                   agdem=agdem+allocrnd(rnd_order(i,1),step);
                                   break
                               end
                           end
                       else
                           if step==1
                               if rnd_order(i,1)>1
                                   if estim(bidstepscum(rnd_order(i,1)-1,1)+step,7)+agdem<=1
                                       allocrnd(rnd_order(i,1),step)=estim(bidstepscum(rnd_order(i,1)-1,1)+step,7);
                                       agdem=agdem+allocrnd(rnd_order(i,1),step);
                                   else
                                        allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                                        agdem=agdem+allocrnd(rnd_order(i,1),step);
                                        break
                                   end
                               else
                                   if estim(step,7)+agdem<=1
                                       allocrnd(rnd_order(i,1),step)=estim(step,7);
                                       agdem=agdem+allocrnd(rnd_order(i,1),step);
                                   else
                                        allocrnd(rnd_order(i,1),step)=1-agdem; %ag supply exceeeded, ration and stop allocating
                                        agdem=agdem+allocrnd(rnd_order(i,1),step);
                                        break
                                   end
                               end
                           end
                       end
                   end
               end               
               if sum(sum(allocrnd))>1+1e-5, disp(['Allocrnd problem: ' sum(sum(allocrnd))]), pause, end
               %agdem=agdem+max(invbidfunc(rnd_order(i,:)));    
               %ration if allocation bigger than 1
            end
            if agdem>=1, break, end
        end                   
        disp(['Allocrnd: ' num2str(sum(sum(allocrnd))) ' Auctiongroup: ' num2str(auctiongroup)])
        %Now we have the random allocation, let's compute the random
        %surplus for each bootstrap draw:       
                               
%%
temp=[];        
for boot=1:bootdraws  %start cycling bootdraws        
help=margvalall{auctiongroup,boot}(spanauc(auction,2):spanauc(auction,3),:).*allocrnd(spanauc(auction,2):spanauc(auction,3),:);
help=sum(help(isnan(help)==0 & isfinite(help)==1));
grossurrnd{auctiongroup,boot}(auction,1)=help; %surplus from random allocation per tbill sold
clear help
%on few occasions there is an outlier in boostrapped margval which will
%then drive std err crazy - eliminate these cases
if actgrossur{auctiongroup,boot}(auction,1)/grossurrnd{auctiongroup,boot}(auction,1)<2 
    temp(boot,1)=actgrossur{auctiongroup,boot}(auction,1)/grossurrnd{auctiongroup,boot}(auction,1);
    efficrnd{auctiongroup,boot}(auction,1)=actgrossur{auctiongroup,boot}(auction,1)/grossurrnd{auctiongroup,boot}(auction,1);
else
    if boot>1 %this should never happen, but to make sure:
        efficrnd{auctiongroup,boot}(auction,1)=mean(temp(1:boot-1,1)); 
        temp(boot,1)=mean(temp(1:boot-1,1));
    else
        efficrnd{auctiongroup,boot}(auction,1)=1;
        temp(1,1)=1;
    end
end
%Now let's do percent covered of effi-random surplus:
if grossuref{auctiongroup,boot}(auction,1)<actgrossur{auctiongroup,boot}(auction,1)
   disp(['Problem: eff s < act s, auctiongroup: ' num2str(auctiongroup)])
end
percentcov{auctiongroup,boot}(auction,1)=(actgrossur{auctiongroup,boot}(auction,1)-grossurrnd{auctiongroup,boot}(auction,1))/(grossuref{auctiongroup,boot}(auction,1)-grossurrnd{auctiongroup,boot}(auction,1));
end %ends boot



% temp=[];
% for i=1:bootdraws
%     temp(i,1)=efficrnd{auctiongroup,i}(auction,1);
% end

%now let's do standard errors for efficiency
expeff(auctiongroup,auction)=0;
effdiff_mean(auctiongroup,auction)=0;
effrndSE(auctiongroup,auction)=0;
percentcovered(auctiongroup,auction)=0;
percent_SE(auctiongroup,auction)=0;
for boot=1:bootdraws
    expeff(auctiongroup,auction)=expeff(auctiongroup,auction)+efficrnd{auctiongroup,boot}(auction,1)/bootdraws;
    percentcovered(auctiongroup,auction)=percentcovered(auctiongroup,auction)+percentcov{auctiongroup,boot}(auction,1)/bootdraws;
    effdiff_mean(auctiongroup,auction)=effdiff_mean(auctiongroup,auction)+(grossurrnd{auctiongroup,boot}(auction,1)-actgrossur{auctiongroup,boot}(auction,1))/(bootdraws*sum(sum(alloc)));    
end
for boot=1:bootdraws
    effrndSE(auctiongroup,auction)=effrndSE(auctiongroup,auction)+(efficrnd{auctiongroup,boot}(auction,1)-expeff(auctiongroup,auction))^2;
    percent_SE(auctiongroup,auction)=percent_SE(auctiongroup,auction)+(percentcov{auctiongroup,boot}(auction,1)-percentcovered(auctiongroup,auction))^2;
end
effrndSE(auctiongroup,auction)=sqrt(effrndSE(auctiongroup,auction))/(bootdraws-1);
percent_SE(auctiongroup,auction)=sqrt(percent_SE(auctiongroup,auction))/(bootdraws-1);
effirnd(auctiongroup,auction)=efficrnd{auctiongroup,1}(auction,1); 
percentcovered(auctiongroup,auction)=percentcov{auctiongroup,1}(auction,1);
end %ends auction loop
end %ends auctiongroup loop
