function[ressup]=resample(boot,supplydev)

% this file takes the matrix of inverse bid functions (in invbidboot) and a particular bidder
% if doing it for an informed one. Then a residual supply function is bootstrapped by taking
% N-1 draws from the matrix, but conditional on fixed number coming from each group
% and  then subtracting these demands from Q. 
% The optional parameter 'supplydev' contains a vector of realization of
% supply deviations, which should be (independently) resampled also

global bidstepscum estim resamplingdraws Group1 Group2 invbidboot oversample supplynoise aucgroupsize auctions

if nargin<2
    supplydev=0;
end

%Importance sampling: bias bids towards non-zero ones
if isempty(oversample)==1;
    redfact=1;
    redfactdealer=1;
else
    redfact=oversample;
    redfactdealer=max(oversample-0.2,1);
end
  
estsize=size(estim);
Q=1; %expected value of supply for bidders
sigmaQ=0.05; %variance of supply if noise included
datasize=size(invbidboot);

if boot==1 %In this case the original sample of bids - hence need to correct for zero bids
    %In each auctiongroup, we should have size(Group1)*aucgroupsize bids by Group1 bidders, and
    %size(Group2)*aucgroupsize bids by Group2 bidders. Let's count the nonzero bids we observe
    %for each group, then we will assign "zero" bids so that the total number
    %of bids in the data is indeed (size(Group1)+size(Group2))*aucgroupsize (we need to include zero bids for
    %resampling) 
    auct=1;
    participants=[0 0]; %1st col: Group1 bidders, 2nd Group2 bidders
    partid=zeros(auctions,max([Group1 Group2])); %entry equals 1 if participating in auction (rows auctions, col bidders)
    %n=1;
    for i=1:estsize(1,1)
        if estim(max(i-1,1),2)~=estim(i,2), auct=auct+1; end
        partid(auct,estim(i,4))=1;
    end    

    for i=1:auct
        submitters=0; otherbidders=0;
        for j=1:max([Group1 Group2])        
            if partid(i,j)==1 && any(j==Group1)
                submitters=submitters+1;
            end
            if partid(i,j)==1 && any(j==Group2)
                otherbidders=otherbidders+1;
            end
        end        
        participants(i,:)=[submitters otherbidders];
    end
 
    submitterzero=size(Group1,2)*aucgroupsize-sum(participants(:,1));
    otherbidderzero=size(Group2,2)*aucgroupsize-sum(participants(:,2));
end

%Initiate a matrix for the residual supply
ressup=zeros(resamplingdraws,datasize(1,2));


%Start iterations

for j=1:resamplingdraws
    
    drawng1=0; %reset draw counters
    drawng2=0;
    
    %Display notice that 2500 or its multiple has been completed
    %if mod(j,2500)==0 disp(['Draws completed']), disp(j), end   

    %Reset current residual supply to full level and add noise if asked for
    if supplynoise==0
        ressup(j,:)=Q;
    else
        ressup(j,:)=normrnd(Q,sigmaQ);
    end
    % resample the supply deviation and subtract it from the supply
    supply_dev=supplydev(ceil(rand*size(supplydev,1)),1);
    ressup(j,:)=ressup(j,:)-supply_dev;
    
    for i=1:(size(Group1,2)+size(Group2,2)-1-drawng2) %start drawing N-1 bid functions with replacement (minus observed bids)
        
         % Start with Group1's bids
     if drawng1<size(Group1,2)        
         bidgroup=0;
         if boot==1 %In this case zero bids are not in the invbidboot
             if rand>submitterzero/(aucgroupsize*redfactdealer*size(Group1,2)) %With thise probability a non-zero bid was submitted by a submitter             
                while all(bidgroup~=Group1) %keep drawing until a bid from this group                              
                       k=ceil(rand*(datasize(1,1)));                    
                    %check if this bidder belongs to group 1
                       if any(estim(bidstepscum(k,1),4)==Group1)
                            bidgroup=estim(bidstepscum(k,1),4);
                            drawng1=drawng1+1;
                            ressup(j,:)=ressup(j,:)-invbidboot(k,:);
                       end
                end
             else
                 drawng1=drawng1+1; %Zero bid is resampled -> no change in ressup(j,:)
             end
         else %Now zero bids are part of invbidboot (First aucgroupsize*size(Group1,1) bids)
             k=ceil(rand*(aucgroupsize*size(Group1,2)));                    
             drawng1=drawng1+1;
             ressup(j,:)=ressup(j,:)-invbidboot(k,:);
         end                                       
     else %Group2's bids:
         bidgroup=0;
         if boot==1 %In this case zero bids are not in the invbidboot
             if rand>otherbidderzero/(aucgroupsize*redfact*size(Group2,2))
                 while all(bidgroup~=Group2) %keep drawing until a bid from this group             
                     k=ceil(rand*datasize(1,1)); %First determine which bid function to draw this round
                     if any(estim(bidstepscum(k,1),4)==Group2)
                        bidgroup=estim(bidstepscum(k,1),4);
                        drawng2=drawng2+1;
                        ressup(j,:)=ressup(j,:)-invbidboot(k,:);
                     end
                 end
             else
                 drawng2=drawng2+1;
             end
         else %Now zero bids are part of invbidboot (Last 148 bids)
             k=aucgroupsize*size(Group1,2)+ceil(rand*(aucgroupsize*size(Group2,2)));                    
             drawng2=drawng2+1;
             ressup(j,:)=ressup(j,:)-invbidboot(k,:);
         end             
     end
           
       
    end %ends drawing bid functions
    
    %Make sure residual supply is nonnegative
    for i=1:datasize(1,2)
        if ressup(j,i)<0
            ressup(j,i)=0;
        end
    end
end


