function []=summary_stat(ltro,groups)
% Summary statistics for ECB auctions. Auction #32 labeled 20070051 (on 8/7/2007) is
% the last before turmoil in MROs, auction #33, labeled 20070055 (on 8/14/2007) is
% the first after turmoil
% In LTROs it is auction 12 that is first after turmoil.
%clear

%For conditional summary statistics before and after turmoil, set cutoff
%auction: last auction to be included from the beginning
if exist('ltro','var')
    if ltro==1
        disp('Summary stats for LTRO data')
        cutoff=11;
    else
        disp('Summary stats for MRO data')
        cutoff=32;
    end
else
    disp('Summary stats for MRO data')
    cutoff=32;
    
end
if exist('groups','var')
    groupnbr=size(groups,2);
end

if cutoff==32 %loading MROs
    load('ecb_data.mat','data')
    load('nuno.mat','agdata') 
else %loading LTROs
    load('data_ltro.mat')
    data=data_ltro_numbers;
    agdata=agdata_ltro;    
end

%load('ecb_main_50_M2_733754','Group1','Group2')
%groups{1,1}=Group1;
%groups{1,2}=Group2;
%group1=Group1;
%group2=Group2;

eonia=agdata(:,13);
global pstep

pstep=0.005;
[estim,bidsteps,bidstepscum,pgrid,invbidfunc,spanauc,span]=dataread(data,0);

%Find cutoff in terms of bidsteps:
bidcutoff=bidstepscum>=span(cutoff,3);

%estim.txt contains data on bids. 1st column is 'Bidder'. 2nd col: auction_id, 
%3rd c: Q issued, 4th c: actual bidder, 5th c: p-bid, 6th: q-bid, 
%7th: cumul demand at p,
datsize=size(estim);

%participants
auctions=1;
unqbidders=unique(estim(:,1));
participants=[0 0]; %1st col: AuctionID, 2nd bidders
partid=zeros(size(span,1),max(unqbidders)); %entry equals 1 if participating in auction (rows auctions, col bidders)
n=1;
for i=1:datsize(1,1)
    if estim(max(i-1,1),2)~=estim(i,2), auctions=auctions+1; end
    partid(auctions,estim(i,4))=1;
end    

for i=1:auctions
    submitters=0;
    for j=1:max(unqbidders)       
        if partid(i,j)==1
            submitters=submitters+1;
        end
    end        
    participants(i,:)=[span(i,1) submitters];
end

disp('Mean # of bidders:'), disp (sum(participants(:,2))/auctions)
disp('St Dev # of bidders:'),  disp(sqrt(var(participants(:,2))))
disp('Min # of bidders:'), disp(min(participants(:,2)))
disp('Max # of bidders:'), disp(max(participants(:,2)))

%Bidsteps
disp('Mean # of bidsteps'), disp(mean(bidsteps))
disp('st Dev # of bidsteps'), disp(sqrt(var(bidsteps)))
disp('Min # of bidsteps'), disp(min(bidsteps))
disp('Max # of bidsteps'), disp(max(bidsteps))

%Pricebid
disp('Mean p bid (in basis points)'), disp(mean(estim(:,5)))
disp('St Dev p bid'), disp(sqrt(var(estim(:,5))))
disp('Min p bid'), disp(min(estim(:,5)))
disp('Max p bid'), disp(max(estim(:,5)))

%adjust price bids by eonia
adjustbid=zeros(size(estim(:,5),1),1);
for i=1:size(agdata,1)
    %FINISH HERE!!!
    temp=(estim(:,2)==agdata(i,1));
    adjustbid(temp)=estim(temp,5)-agdata(i,13); %normalize by eonia
end
disp('Mean (p bid - EONIA) (in basis points)'), disp(mean(adjustbid))
disp('St Dev (p bid - EONIA)'), disp(sqrt(var(adjustbid)))
disp('Min (p bid - EONIA)'), disp(min(adjustbid))
disp('Max (p bid - EONIA)'), disp(max(adjustbid))


%Quantitybid
disp('Mean Q-share bid'), disp(mean(estim(:,7)))
disp('St Dev Q-share bid'), disp(sqrt(var(estim(:,7))))
disp('1000*Min Q-share bid'), disp(min(estim(:,7))*1000)
disp('Max Q-share bid'), disp(max(estim(:,7)))

%Issued quantity
meanq=estim(1,3)/auctions;
for i=2:datsize(1,1)
    if estim(i,2)~=estim(i-1,2)
        meanq=meanq+estim(i,3)/auctions;
    end
end
varq=(estim(1,3)-meanq)^2/(auctions-1);
for i=2:datsize(1,1)
    if estim(i,2)~=estim(i-1,2)
        varq=varq+(estim(i,3)-meanq)^2/(auctions-1);
    end
end
disp('Mean issued Q (in billions)'), disp(meanq/1000)
disp('St Dev issued Q (in millions)'), disp(sqrt(varq))
disp('Min issued Q (in billions)'), disp(min(estim(:,3))/1000)
disp('Max issued Q (in billions)'), disp(max(estim(:,3))/1000)

if cutoff<auctions
    %Conditional summary statistics
    disp('BEFORE Mean # of bidders:'), disp (mean(participants(1:cutoff,2)))
    disp('AFTER Mean # of bidders:'), disp (mean(participants(cutoff+1:end,2)))
    disp('BEFORE St Dev # of bidders:'),  disp(sqrt(var(participants(1:cutoff,2))))
    disp('AFTER St Dev # of bidders:'),  disp(sqrt(var(participants(cutoff+1:end,2))))
    disp('BEFORE Min # of bidders:'), disp(min(participants(1:cutoff,2)))
    disp('AFTER Min # of bidders:'), disp(min(participants(cutoff+1:end,2)))
    disp('BEFORE Max # of bidders:'), disp(max(participants(1:cutoff,2)))
    disp('AFTER Max # of bidders:'), disp(max(participants(cutoff+1:end,2)))

    befcutoff=(ones(size(bidsteps,1),1)-bidcutoff)>0;
    disp('BEFORE Mean # of bidsteps:'), disp (mean(bidsteps(befcutoff,:)))
    disp('AFTER Mean # of bidsteps:'), disp (mean(bidsteps(bidcutoff,:)))
    disp('BEFORE St Dev # of bidsteps:'),  disp(sqrt(var(bidsteps(befcutoff,:))))
    disp('AFTER St Dev # of bidsteps:'),  disp(sqrt(var(bidsteps(bidcutoff,:))))
    disp('BEFORE Min # of bidsteps:'), disp(min(bidsteps(befcutoff,:)))
    disp('AFTER Min # of bidsteps:'), disp(min(bidsteps(bidcutoff,:)))
    disp('BEFORE Max # of bidsteps:'), disp(max(bidsteps(befcutoff,:)))
    disp('AFTER Max # of bidsteps:'), disp(max(bidsteps(bidcutoff,:)))

    disp('BEFORE Mean p bid (in basis points)'), disp(mean(estim(1:span(cutoff,3),5)))
    disp('AFTER Mean p bid (in basis points)'), disp(mean(estim(span(cutoff+1,2):end,5)))
    disp('BEFORE St Dev p bid'), disp(sqrt(var(estim(1:span(cutoff,3),5))))
    disp('AFTER St Dev p bid'), disp(sqrt(var(estim(span(cutoff+1,2):end,5))))
    disp('BEFORE Min p bid'), disp(min(estim(1:span(cutoff,3),5)))
    disp('AFTER Min p bid'), disp(min(estim(span(cutoff+1,2):end,5)))
    disp('BEFORE Max p bid'), disp(max(estim(1:span(cutoff,3),5)))
    disp('AFTER Max p bid'), disp(max(estim(span(cutoff+1,2):end,5)))

    disp('BEFORE Mean  (p bid - EONIA) (in basis points)'), disp(mean(adjustbid(1:span(cutoff,3))))
    disp('AFTER Mean (p bid - EONIA) (in basis points)'), disp(mean(adjustbid(span(cutoff+1,2):end)))
    disp('BEFORE St Dev (p bid - EONIA)'), disp(sqrt(var(adjustbid(1:span(cutoff,3)))))
    disp('AFTER St Dev (p bid - EONIA)'), disp(sqrt(var(adjustbid(span(cutoff+1,2):end))))
    disp('BEFORE Min (p bid - EONIA)'), disp(min(adjustbid(1:span(cutoff,3))))
    disp('AFTER Min (p bid - EONIA)'), disp(min(adjustbid(span(cutoff+1,2):end)))
    disp('BEFORE Max (p bid - EONIA)'), disp(max(adjustbid(1:span(cutoff,3))))
    disp('AFTER Max (p bid - EONIA)'), disp(max(adjustbid(span(cutoff+1,2):end)))

    disp('BEFORE Mean Q-share bid '), disp(mean(estim(1:span(cutoff,3),7)))
    disp('AFTER Mean Q-share bid '), disp(mean(estim(span(cutoff+1,2):end,7)))
    disp('BEFORE St Dev Q-share bid'), disp(sqrt(var(estim(1:span(cutoff,3),7))))
    disp('AFTER St Dev Q-share bid'), disp(sqrt(var(estim(span(cutoff+1,2):end,7))))
    disp('BEFORE Min Q-share bid'), disp(min(estim(1:span(cutoff,3),7)))
    disp('AFTER Min Q-share bid'), disp(min(estim(span(cutoff+1,2):end,7)))
    disp('BEFORE Max Q-share bid'), disp(max(estim(1:span(cutoff,3),7)))
    disp('AFTER Max Q-share bid'), disp(max(estim(span(cutoff+1,2):end,7)))

    %Issued quantity
    meanq_bef=estim(1,3)/cutoff;
    for i=2:span(cutoff,3)
        if estim(i,2)~=estim(i-1,2)
            meanq_bef=meanq_bef+estim(i,3)/cutoff;
        end
    end
    varq_bef=(estim(1,3)-meanq_bef)^2/(cutoff-1);
    for i=2:span(cutoff,3)
        if estim(i,2)~=estim(i-1,2)
            varq_bef=varq_bef+(estim(i,3)-meanq_bef)^2/(cutoff-1);
        end
    end
    meanq_aft=estim(span(cutoff+1,2),3)/(size(span,1)-cutoff);
    for i=span(cutoff+1,2)+1:datsize(1,1)
        if estim(i,2)~=estim(i-1,2)
            meanq_aft=meanq_aft+estim(i,3)/(size(span,1)-cutoff);
        end
    end
    varq_aft=(estim(span(cutoff+1,2),3)-meanq_aft)^2/(size(span,1)-cutoff);
    for i=span(cutoff+1,2)+1:datsize(1,1)
        if estim(i,2)~=estim(i-1,2)
            varq_aft=varq_aft+(estim(i,3)-meanq_aft)^2/(size(span,1)-cutoff);
        end
    end

    disp('BEFORE Mean issued Q (in billions) '), disp(meanq_bef/1000)
    disp('AFTER Mean issued Q (in billions) '), disp(meanq_aft/1000)
    disp('BEFORE St Dev issued Q (in millions)'), disp(sqrt(varq_bef))
    disp('AFTER St Dev issued Q (in millions)'), disp(sqrt(varq_aft))
    disp('BEFORE Min issued Q (in billions)'), disp(min(estim(1:span(cutoff,3),3))/1000)
    disp('AFTER Min issued Q (in billions)'), disp(min(estim(span(cutoff+1,2):end,3))/1000)
    disp('BEFORE Max issued Q (in billions)'), disp(max(estim(1:span(cutoff,3),3))/1000)
    disp('AFTER Max issued Q (in billions)'), disp(max(estim(span(cutoff+1,2):end,3))/1000)
end % finish if-statement (auctions>= cutoff)

if exist('groups','var')    %in this case groups of bidders were supplied  
    %tempg store line numbers in 'estim' where bidders
    %belonging to group g appear
    for g=1:groupnbr
        tempg{1,g}=[];
        for i=1:size(groups{1,g},2)
            temp=find(estim(:,4)==groups{1,g}(1,i));
            tempg{1,g}=[tempg{1,g}; temp];
        end
        %tempbidg store line number in 'bidsteps' where bidders
        %belonging to group g appear
        tempbidg{1,g}=[];
        for i=1:size(bidstepscum,1)            
            if any(groups{1,g}==estim(bidstepscum(i,1),4))
                tempbidg{1,g}=[tempbidg{1,g}; i];
            end
        end
    end
    
    for g=1:size(tempg,2)
        %Bidsteps
        disp(['Mean # of bidsteps, G' num2str(g)]), disp(mean(bidsteps(tempbidg{1,g})))
        disp(['st Dev # of bidsteps,G' num2str(g)]), disp(sqrt(var(bidsteps(tempbidg{1,g}))))
        disp(['Min # of bidsteps,G' num2str(g)]), disp(min(bidsteps(tempbidg{1,g})))
        disp(['Max # of bidsteps G' num2str(g)]), disp(max(bidsteps(tempbidg{1,g})))

        %Pricebid
        disp(['Mean p bid (in basis points), G' num2str(g)]), disp(mean(estim(tempg{1,g},5)))
        disp(['St Dev p bid, G' num2str(g)]), disp(sqrt(var(estim(tempg{1,g},5))))
        disp(['Min p bid, G' num2str(g)]), disp(min(estim(tempg{1,g},5)))
        disp(['Max p bid, G' num2str(g)]), disp(max(estim(tempg{1,g},5)))

        %adjusted price bids by eonia
        disp(['Mean (p bid - EONIA) (in basis points), G' num2str(g)]), disp(mean(adjustbid(tempg{1,g})))
        disp(['St Dev (p bid - EONIA), G' num2str(g)]), disp(sqrt(var(adjustbid(tempg{1,g}))))
        disp(['Min (p bid - EONIA), G' num2str(g)]), disp(min(adjustbid(tempg{1,g})))
        disp(['Max (p bid - EONIA), G' num2str(g)]), disp(max(adjustbid(tempg{1,g})))


        %Quantitybid
        disp(['Mean Q-share bid, G' num2str(g)]), disp(mean(estim(tempg{1,g},7)))
        disp(['St Dev Q-share bid, G' num2str(g)]), disp(sqrt(var(estim(tempg{1,g},7))))
        disp(['1000*Min Q-share bid, G' num2str(g)]), disp(min(estim(tempg{1,g},7))*1000)
        disp(['Max Q-share bid, G' num2str(g)]), disp(max(estim(tempg{1,g},7)))

    end
    
    %As above, but now pre- and post-turmoil
    for g=1:size(tempg,2)
        before_ind_cutoff=find(bidstepscum==span(cutoff,3)); %last index in bidstep before turmoil
        bef_ind=tempbidg{1,g}(tempbidg{1,g}<=before_ind_cutoff);
        after_ind=tempbidg{1,g}(tempbidg{1,g}>before_ind_cutoff);
        disp(['BEFORE Mean # of bidsteps, G' num2str(g)]), disp (mean(bidsteps(bef_ind,:)))
        disp(['AFTER Mean # of bidsteps, G' num2str(g)]), disp (mean(bidsteps(after_ind,:)))
        disp(['BEFORE St Dev # of bidsteps, G' num2str(g)]),  disp(sqrt(var(bidsteps(bef_ind,:))))
        disp(['AFTER St Dev # of bidsteps, G' num2str(g)]),  disp(sqrt(var(bidsteps(after_ind,:))))
        disp(['BEFORE Min # of bidsteps, G' num2str(g)]), disp(min(bidsteps(bef_ind,:)))
        disp(['AFTER Min # of bidsteps, G' num2str(g)]), disp(min(bidsteps(after_ind,:)))
        disp(['BEFORE Max # of bidsteps, G' num2str(g)]), disp(max(bidsteps(bef_ind,:)))
        disp(['AFTER Max # of bidsteps, G' num2str(g)]), disp(max(bidsteps(after_ind,:)))
        
        before_ind_cutoff=span(cutoff,3); %last index in estim before turmoil
        bef_ind=tempg{1,g}(tempg{1,g}<=before_ind_cutoff);
        after_ind=tempg{1,g}(tempg{1,g}>before_ind_cutoff);        
        disp(['BEFORE Mean p bid (in basis points), G' num2str(g)]), disp(mean(estim(bef_ind,5)))
        disp(['AFTER Mean p bid (in basis points), G' num2str(g)]), disp(mean(estim(after_ind,5)))
        disp(['BEFORE St Dev p bid, G' num2str(g)]), disp(sqrt(var(estim(bef_ind,5))))
        disp(['AFTER St Dev p bid, G' num2str(g)]), disp(sqrt(var(estim(after_ind,5))))
        disp(['BEFORE Min p bid, G' num2str(g)]), disp(min(estim(bef_ind,5)))
        disp(['AFTER Min p bid, G' num2str(g)]), disp(min(estim(after_ind,5)))
        disp(['BEFORE Max p bid, G' num2str(g)]), disp(max(estim(bef_ind,5)))
        disp(['AFTER Max p bid, G' num2str(g)]), disp(max(estim(after_ind,5)))

        disp(['BEFORE Mean  (p bid - EONIA) (in basis points), G' num2str(g)]), disp(mean(adjustbid(bef_ind)))
        disp(['AFTER Mean (p bid - EONIA) (in basis points), G' num2str(g)]), disp(mean(adjustbid(after_ind)))
        disp(['BEFORE St Dev (p bid - EONIA), G' num2str(g)]), disp(sqrt(var(adjustbid(bef_ind))))
        disp(['AFTER St Dev (p bid - EONIA), G' num2str(g)]), disp(sqrt(var(adjustbid(after_ind))))
        disp(['BEFORE Min (p bid - EONIA), G' num2str(g)]), disp(min(adjustbid(bef_ind)))
        disp(['AFTER Min (p bid - EONIA), G' num2str(g)]), disp(min(adjustbid(after_ind)))
        disp(['BEFORE Max (p bid - EONIA), G' num2str(g)]), disp(max(adjustbid(bef_ind)))
        disp(['AFTER Max (p bid - EONIA), G' num2str(g)]), disp(max(adjustbid(after_ind)))

        disp(['BEFORE Mean Q-share bid, G' num2str(g)]), disp(mean(estim(bef_ind,7)))
        disp(['AFTER Mean Q-share bid, G' num2str(g)]), disp(mean(estim(after_ind,7)))
        disp(['BEFORE St Dev Q-share bid, G' num2str(g)]), disp(sqrt(var(estim(bef_ind,7))))
        disp(['AFTER St Dev Q-share bid, G' num2str(g)]), disp(sqrt(var(estim(after_ind,7))))
        disp(['BEFORE Min Q-share bid, G' num2str(g)]), disp(min(estim(bef_ind,7)))
        disp(['AFTER Min Q-share bid, G' num2str(g)]), disp(min(estim(after_ind,7)))
        disp(['BEFORE Max Q-share bid, G' num2str(g)]), disp(max(estim(bef_ind,7)))
        disp(['AFTER Max Q-share bid, G' num2str(g)]), disp(max(estim(after_ind,7)))
    end
    
end

partfreq=sum(partid);
hist(partid)
hist(partfreq)
partfreq_pre=sum(partid(1:32,:));
partfreq_post=sum(partid(33:end,:));

partfreq_pre=partfreq_pre./32;
partfreq_post=partfreq_post./18;
corr(partfreq_pre',partfreq_post')

subplot(2,1,1)
hist(partfreq_pre)
title(['Histogram of participation frequency before turmoil'])
subplot(2,1,2)
hist(partfreq_post)
title(['Histogram of participation frequency after turmoil'])

% analysis of bidder specific distribution of market clearing price
load('ecb_main_mro_50_M3_733890.mat','meanp','stddevp','Group1','Group2')
%normalize means of price distribution by EONIA:
temp=meanp==0;
meanp=meanp-repmat(agdata(:,13),1,size(meanp,2));
meanp(temp)=0;

disp(['Mean of std dev of p-dist: ' num2str(mean(stddevp(stddevp>0)))])
disp(['Mean of means of p-dist: ' num2str(mean(meanp(meanp~=0)))])
meanp_pre=meanp(1:32,:);
meanp_post=meanp(32:end,:);
stddevp_pre=stddevp(1:32,:);
stddevp_post=stddevp(33:end,:);
disp(['Mean of means of p-dist PRE: ' num2str(mean(meanp_pre(meanp_pre~=0)))])
%ans =
%    3.7901
%ans =
%   -0.0137
disp(['Mean of means of p-dist POST: ' num2str(mean(meanp_post(meanp_post~=0)))])
%ans =
%    0.0983
%ans =
%    4.1337
disp(['Mean of std dev of p-dist PRE: ' num2str(mean(stddevp_pre(stddevp_pre>0)))])
%ans =
%    0.0112
disp(['Mean of std dev of p-dist POST: ' num2str(mean(stddevp_post(stddevp_post>0)))])
%ans =
%    0.0223
meanp_g1_pre=meanp_pre(:,Group1);
disp(['Mean of means of p-dist PRE G1: ' num2str(mean(meanp_g1_pre(meanp_g1_pre~=0)))])
meanp_g2_pre=meanp_pre(:,Group2);
disp(['Mean of means of p-dist PRE G2: ' num2str(mean(meanp_g2_pre(meanp_g2_pre~=0)))])
meanp_g1_post=meanp_post(:,Group1);
disp(['Mean of means of p-dist POST G1: ' num2str(mean(meanp_g1_post(meanp_g1_post~=0)))])
meanp_g2_post=meanp_post(:,Group2);
disp(['Mean of means of p-dist POST G2: ' num2str(mean(meanp_g2_post(meanp_g2_post~=0)))])
stddevp_g1_pre=stddevp_pre(:,Group1);
disp(['Mean of std dev of p-dist PRE G1: ' num2str(mean(stddevp_g1_pre(stddevp_g1_pre>0)))])
stddevp_g2_pre=stddevp_pre(:,Group2);
disp(['Mean of std dev of p-dist PRE G2: ' num2str(mean(stddevp_g2_pre(stddevp_g2_pre>0)))])
stddevp_g1_post=stddevp_post(:,Group1);
disp(['Mean of std dev of p-dist POST G1: ' num2str(mean(stddevp_g1_post(stddevp_g1_post>0)))])
stddevp_g2_post=stddevp_post(:,Group2);
disp(['Mean of std dev of p-dist POST G2: ' num2str(mean(stddevp_g2_post(stddevp_g2_post>0)))])

% Figure out Q-shares won by each group:
% Find equilibrium allocation by auction:
for i=1:auctions
   trueressup=sum(invbidfunc(spanauc(i,2):spanauc(i,3),:));
   truepclear(i,1)=pgrid(1,find(trueressup>1,1,'last'));
   true_ratcoef(i,1)=(1-trueressup(1,find(trueressup>1,1,'last')+1))/(trueressup(1,find(trueressup>1,1,'last'))-trueressup(1,find(trueressup>1,1,'last')+1));
   alloc_g1(i,1:2)=[0 1];
   alloc_g2(i,1:2)=[0 1];
   
   for j=span(i,2):span(i,3)
       if estim(j,5)>=truepclear(i,1)-0.001
           if estim(j,5)>=truepclear(i,1)+0.001 % full demand satisfied
               if any(Group1==estim(j,4))
                    alloc_g1(i,1)=alloc_g1(i,1)+estim(j,6);
                    if estim(max(j-1,1),4)~=estim(j,4)
                        alloc_g1(i,2)=alloc_g1(i,2)+1;
                    end
               else
                    alloc_g2(i,1)=alloc_g2(i,1)+estim(j,6);   
                    if estim(max(j-1,1),4)~=estim(j,4)
                        alloc_g2(i,2)=alloc_g2(i,2)+1;
                    end
               end
           else % rationing
               if any(Group1==estim(j,4))
                    alloc_g1(i,1)=alloc_g1(i,1)+estim(j,6)*true_ratcoef(i,1);
                    if estim(max(j-1,1),4)~=estim(j,4)
                        alloc_g1(i,2)=alloc_g1(i,2)+1;
                    end
               else
                    alloc_g2(i,1)=alloc_g2(i,1)+estim(j,6)*true_ratcoef(i,1); 
                    if estim(max(j-1,1),4)~=estim(j,4)
                        alloc_g2(i,2)=alloc_g2(i,2)+1;
                    end
               end
           end
       end
   end
   
end
% to check allocation sums to 1
alloc= alloc_g1+ alloc_g2;
agsup=agdata(:,7)/max(agdata(:,7));
% conditional on positive allocation, avg allocation within group:
alloc_g1(:,3)=alloc_g1(:,1)./alloc_g1(:,2);
alloc_g2(:,3)=alloc_g2(:,1)./alloc_g2(:,2);
figure
plot(alloc_g2(:,3)*100,'r')
hold on
plot(alloc_g1(:,3)*100)
plot(agsup,'k')
plot([32 32], [ 0.0 1.4], '-.')
title(['Average Allocation By Bidder Group  (conditional on positive allotment)'])
legend('Avg Allocation to a Distressed Bank','Avg Allocation to a Healthy Bank', 'Aggregate Supply','Turmoil','Location','NorthWest')
xlabel('Auction')
ylabel('% of Supply')

figure
plot(alloc_g2(:,1)*100,'r')
hold on
plot(alloc_g1(:,1)*100)
plot(agsup*100,'k')
plot([32 32], [ 0.0 100], '-.')
title(['Allocation By Bidder Group'])
legend('Fraction of Supply Allocated to Distressed Banks','Fraction of Supply Allocated  to Healthy Banks',  'Aggregate Supply','Turmoil','Location','West')
xlabel('Auction')
ylabel('% of Supply')

figure
plot(alloc_g2(:,2),'r')
hold on
plot(alloc_g1(:,2))
%plot(agsup,'k')
plot([32 32], [ 0.0 300], '-.')
title(['Winning Bidders by Group'])
legend('Winners Among Distressed Banks','Winners Among Healthy Banks', 'Turmoil','Location','NorthEast')
xlabel('Auction')
ylabel('Number of Banks')




